@@ -31,7 +31,7 @@ namespace afnix {
   class Resume : public Object {
   public:
     /// create a default resume
-    Resume (void);
+    Resume (void) =default;
     
     /// copy move this resume
     /// @param that the resume to move
