@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2020 amaury darsch                                   -
+// - copyright (c) 1999-2021 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Cons.hpp"
@@ -259,10 +259,11 @@ namespace afnix {
   Object* Class::oper (t_oper type, Object* object) {
     Class* cobj = dynamic_cast <Class*> (object);
     switch (type) {
-    case Object::EQL:
+    case Object::OPER_EQL:
+    case Object::OPER_QEQ:
       if (cobj != nullptr) return new Boolean (this == cobj);
       break;
-    case Object::NEQ:
+    case Object::OPER_NEQ:
       if (cobj != nullptr) return new Boolean (this != cobj);
       break;
     default:
