@@ -25,21 +25,33 @@ namespace afnix {
   // - class section                                                         -
   // -------------------------------------------------------------------------
 
-  // create a default former
-
-  Former::Former (void) {
-  }
-  
   // copy move this former
 
-  Former::Former (Former&& that) noexcept :
-    Object (static_cast<Object&&>(that)) {
+  Former::Former (Former&& that) noexcept {
+    that.wrlock ();
+    try {
+      // assign the base object
+      Object::operator = (static_cast<Object&&>(that));
+    } catch (...) {
+    }
+    that.unlock ();
   }
   
   // move this former into this one
 
   Former& Former::operator = (Former&& that) noexcept {
-    Object::operator = (static_cast<Object&&>(that));
+    // check for self assignation
+    if (this == &that) return *this;
+    // lock and assign
+    wrlock ();
+    that.wrlock ();
+    try {
+      // assign base object
+      Object::operator = (static_cast<Object&&>(that));
+    } catch (...) {
+    }
+    unlock ();
+    that.unlock ();
     return *this;
   }
   
