@@ -31,7 +31,7 @@ namespace afnix {
   class Former : public virtual Object {
   public:
     /// create a default former
-    Former (void);
+    Former (void) = default;
     
     /// copy move this former
     /// @param that the former to move
