@@ -30,7 +30,7 @@
 #include "Plist.hpp"
 #include "Lockf.hpp"
 #include "Engsrl.hxx"
-#include "Global.hpp"
+#include "Common.hpp"
 #include "Locale.hpp"
 #include "Logger.hpp"
 #include "Interp.hpp"
@@ -42,6 +42,7 @@
 #include "Bitset.hpp"
 #include "Symbol.hpp"
 #include "Numeral.hpp"
+#include "Complex.hpp"
 #include "Message.hpp"
 #include "Lexical.hpp"
 #include "Relatif.hpp"
@@ -188,6 +189,7 @@ namespace afnix {
     interp->mkrsv ("integer-p",      new Function (Builtin::sfintp));
     interp->mkrsv ("relatif-p",      new Function (Builtin::sfrltp));
     interp->mkrsv ("numeral-p",      new Function (Builtin::sfnumrp));
+    interp->mkrsv ("complex-p",      new Function (Builtin::sfcplxp));
     interp->mkrsv ("literal-p",      new Function (Builtin::sflitp));
     interp->mkrsv ("closure-p",      new Function (Builtin::sfclop));
     interp->mkrsv ("nameset-p",      new Function (Builtin::sfnstp));
@@ -242,6 +244,7 @@ namespace afnix {
     interp->mkrsv ("Relatif",        new Meta (Relatif::mknew));    
     interp->mkrsv ("Integer",        new Meta (Integer::mknew));
     interp->mkrsv ("Numeral",        new Meta (Numeral::meval, Numeral::mknew));
+    interp->mkrsv ("Complex",        new Meta (Complex::mknew));
     interp->mkrsv ("Boolean",        new Meta (Boolean::mknew));
     interp->mkrsv ("Closure",        new Meta (Closure::mknew));
     interp->mkrsv ("Counter",        new Meta (Counter::mknew));
@@ -946,7 +949,7 @@ namespace afnix {
       // set the arguments
       setargs (args);
       // set the assert flag
-      Global::setasrt (opts.getoflg ('f', "assert"));
+      Common::setasrt (opts.getoflg ('f', "assert"));
       // get the resolver path
       setpath (opts.getoptv ('i'));
       // set the encoding mode
