@@ -54,6 +54,8 @@ namespace afnix {
   static const t_quad LEX_CHAR_BL = 0x00000062UL; // b
   static const t_quad LEX_CHAR_EU = 0x00000045UL; // E
   static const t_quad LEX_CHAR_EL = 0x00000065UL; // e
+  static const t_quad LEX_CHAR_IU = 0x00000049UL; // I
+  static const t_quad LEX_CHAR_IL = 0x00000069UL; // i
   static const t_quad LEX_CHAR_NL = 0x0000006EUL; // n
   static const t_quad LEX_CHAR_RU = 0x00000052UL; // R
   static const t_quad LEX_CHAR_RL = 0x00000072UL; // r
@@ -138,12 +140,13 @@ namespace afnix {
 
   Token Lexer::get (void) {
     // reset controls
-    bool   eflag  = false;
-    bool   esign  = false;
-    bool   eonly  = false;
-    long   rcount = 0;
-    t_quad clast  = nilq;
-
+    bool   spnt = false;
+    bool   eflg = false;
+    bool   esgn = false;
+    bool   enly = false;
+    long   rcnt = 0L;
+    t_quad clst = nilq;
+    
     // check for nil stream and reset buffer
     if (p_is == nullptr) return Token (Token::ERROR,d_lnum);
     d_cbuf.reset ();
@@ -177,7 +180,7 @@ namespace afnix {
     case LEX_CHAR_DQ:
       goto s_string;
     case LEX_CHAR_LB:
-      rcount++;
+      rcnt++;
       d_cbuf.add (c);
       goto s_regex;
     case LEX_CHAR_PS:
@@ -233,7 +236,7 @@ namespace afnix {
       goto s_lexical;
     }
     if (c == LEX_CHAR_DP) {
-      d_cbuf.add (clast = c);
+      d_cbuf.add (clst = c);
       goto s_qualified;
     }
     if (Lexical::valid (c) == true) {
@@ -254,18 +257,18 @@ namespace afnix {
       goto s_qualified;
     }
     if ((Lexical::valid (c) == true) || (c == LEX_CHAR_DP)) {
-      if ((clast == LEX_CHAR_DP) && (c == LEX_CHAR_DP)) {
+      if ((clst == LEX_CHAR_DP) && (c == LEX_CHAR_DP)) {
 	d_cbuf.add (c);
 	goto s_error;
       }
-      d_cbuf.add (clast = c);
+      d_cbuf.add (clst = c);
       goto s_qualified;
     }
     if (Unicode::isncc (c) == false) {
       d_cbuf.add (c);
       goto s_error;
     }
-    if (clast == LEX_CHAR_DP) goto s_error;
+    if (clst == LEX_CHAR_DP) goto s_error;
     p_is->pushback (c);
     return Token (Token::QUALIFIED, d_cbuf.tostring (), d_lnum);
 
@@ -320,6 +323,7 @@ namespace afnix {
     }
     if (c == LEX_CHAR_SP) {
       d_cbuf.add (c);
+      spnt = true;
       goto s_real;
     }
     if (Lexical::valid (c) == true) {
@@ -410,24 +414,39 @@ namespace afnix {
       d_lnum += lex_flush_cz (p_is);
       goto s_real;
     }
+    if ((c == LEX_CHAR_IL) || (c == LEX_CHAR_IU)) {
+      d_cbuf.add (c);
+      goto s_complex;
+    }
     if (Unicode::isdigit (c) == true) {
-      if ((eflag == true) && (eonly == true)) eonly = false;
+      if ((eflg == true) && (enly == true)) enly = false;
+      if ((eflg == true) && (esgn == true)) esgn = false;
       d_cbuf.add (c);
       goto s_real;
     }
-    if (((c == LEX_CHAR_EL) || (c == LEX_CHAR_EU)) && (eflag == false)) {
+    if (((c == LEX_CHAR_EL) || (c == LEX_CHAR_EU)) && (eflg == false)) {
       d_cbuf.add (LEX_CHAR_EL);
-      eflag = true;
-      eonly = true;
+      eflg = true;
+      enly = true;
       goto s_real;
     }
     if (((c == LEX_CHAR_PS) || (c == LEX_CHAR_MS)) && 
-	(eflag == true) && (esign == false) && (eonly == true)) {
+	(eflg == true) && (esgn == false) && (enly == true)) {
       d_cbuf.add (c);
-      esign = true;
-      eonly = false;
+      esgn = true;
+      enly = false;
       goto s_real;
     }
+    if (((c == LEX_CHAR_PS) || (c == LEX_CHAR_MS)) &&
+	((eflg == false) ||
+	 ((eflg == true) && (enly == false) && (esgn == false)))) {
+      d_cbuf.add (c);
+      spnt = false;
+      eflg = false;
+      enly = false;
+      esgn = false;
+      goto s_cplx;
+    }
     if (Lexical::valid (c) == true) {
       d_cbuf.add (c);
       goto s_lexical;
@@ -439,6 +458,68 @@ namespace afnix {
     p_is->pushback (c);
     return Token (Token::REAL, d_cbuf.tostring (), d_lnum);
 
+  s_cplx:
+    c = p_is->getu ();
+    if (c == LEX_CHAR_LS) {
+      d_lnum += lex_flush_cz (p_is);
+      goto s_cplx;
+    }
+    if ((c == LEX_CHAR_SP) && (spnt == false)) {
+      d_cbuf.add (c);
+      spnt = true;
+      goto s_cplx;
+    }
+    if ((c == LEX_CHAR_IL) || (c == LEX_CHAR_IU)) {
+      d_cbuf.add (c);
+      goto s_complex;
+    }
+    if (Unicode::isdigit (c) == true) {
+      if ((eflg == true) && (enly == true)) enly = false;
+      if ((eflg == true) && (esgn == true)) esgn = false;
+      d_cbuf.add (c);
+      goto s_cplx;
+    }
+    if (((c == LEX_CHAR_EL) || (c == LEX_CHAR_EU)) && (eflg == false)) {
+      d_cbuf.add (LEX_CHAR_EL);
+      eflg = true;
+      enly = true;
+      goto s_cplx;
+    }
+    if (((c == LEX_CHAR_PS) || (c == LEX_CHAR_MS)) && 
+	(eflg == true) && (esgn == false) && (enly == true)) {
+      d_cbuf.add (c);
+      esgn = true;
+      enly = false;
+      goto s_cplx;
+    }
+    if (Lexical::valid (c) == true) {
+      d_cbuf.add (c);
+      goto s_lexical;
+    }
+    if (Unicode::isncc (c) == false) {
+      d_cbuf.add (c);
+      goto s_error;
+    }
+    p_is->pushback (c);
+    goto s_lexical;
+
+  s_complex:
+    c = p_is->getu ();
+    if (c == LEX_CHAR_LS) {
+      d_lnum += lex_flush_cz (p_is);
+      goto s_complex;
+    }
+    if (Lexical::valid (c) == true) {
+      d_cbuf.add (c);
+      goto s_lexical;
+    }
+    if (Unicode::isncc (c) == false) {
+      d_cbuf.add (c);
+      goto s_error;
+    }
+    p_is->pushback (c);
+    return Token (Token::COMPLEX, d_cbuf.tostring (), d_lnum);
+    
   s_character:
     c = p_is->getu ();
     if (c == LEX_CHAR_SQ) 
@@ -514,13 +595,13 @@ namespace afnix {
       goto s_error;
     case LEX_CHAR_LB:
       d_cbuf.add (c);
-      rcount++;
+      rcnt++;
       goto s_regex;
     case LEX_CHAR_RB:
       d_cbuf.add (c);
-      if (--rcount == 0) 
+      if (--rcnt == 0) 
 	return Token (Token::REGEX, d_cbuf.tostring (), d_lnum);
-      if (rcount < 0) goto s_error;
+      if (rcnt < 0) goto s_error;
       goto s_regex;
     default:
       d_cbuf.add (c);
