@@ -16,7 +16,7 @@
 
 #include "Cons.hpp"
 #include "Real.hpp"
-#include "Global.hpp"
+#include "Common.hpp"
 #include "Builtin.hpp"
 #include "Boolean.hpp"
 #include "Evaluable.hpp"
@@ -354,7 +354,7 @@ namespace afnix {
     // check for nil
     if ((obj1 == nullptr) && (obj2 == nullptr)) return nullptr;
     // do nothing if assert flag is false
-    if (Global::getasrt () == false) {
+    if (Common::getasrt () == false) {
       Object::dref (obj1);
       Object::dref (obj2);
       return nullptr;
