@@ -41,6 +41,7 @@
 #include "Symbol.hpp"
 #include "Future.hpp"
 #include "Numeral.hpp"
+#include "Complex.hpp"
 #include "Message.hpp"
 #include "Options.hpp"
 #include "Lexical.hpp"
@@ -210,6 +211,15 @@ namespace afnix {
     return new Boolean (result);
   }
 
+  // cplxp: complex predicate
+
+  Object* Builtin::sfcplxp (Evaluable* zobj, Nameset* nset, Cons* args) {
+    Object* obj = get_obj (zobj, nset, args, "complex-p");
+    bool result = (dynamic_cast <Complex*> (obj) == nullptr) ? false : true;
+    Object::cref (obj);
+    return new Boolean (result);
+  }
+
   // bytep: byte predicate
 
   Object* Builtin::sfbytep (Evaluable* zobj, Nameset* nset, Cons* args) {
