@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2020 amaury darsch                                   -
+// - copyright (c) 1999-2021 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Cons.hpp"
@@ -75,7 +75,8 @@ namespace afnix {
       // check for equality between the selector and the condition
       Object*  data = (cond == nullptr) ? nullptr : cond->eval (zobj, nset);
       Object::iref (data);
-      Object*  bobj = (sel == nullptr) ? nullptr:sel->oper (Object::EQL,data);
+      Object*  bobj =
+	(sel == nullptr) ? nullptr:sel->oper (Object::OPER_EQL, data);
       Boolean* bval = dynamic_cast <Boolean*> (bobj);
       bool     bloc = (bval == nullptr) ? false : bval->tobool ();
       Object::cref (bval);
