@@ -14,12 +14,12 @@
 // - copyright (c) 1999-2021 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
-#include "Real.hpp"
 #include "Token.hpp"
 #include "Regex.hpp"
 #include "Strvec.hpp"
 #include "Boolean.hpp"
 #include "Relatif.hpp"
+#include "Complex.hpp"
 #include "Lexical.hpp"
 #include "Constant.hpp"
 #include "Reserved.hpp"
@@ -95,6 +95,9 @@ namespace afnix {
     case Token::REAL:
       p_object = new Constant (new Real (value));
       break;
+    case Token::COMPLEX:
+      p_object = new Constant (new Complex (value));
+      break;
     case Token::STRING:
       p_object = new Constant (new String (value));
       break;
