@@ -31,24 +31,26 @@ namespace afnix {
   class Token : public Object {
   public:
     /// the various token type
-    enum t_token {
-      ERROR,
-      EOL,
-      EOS,
-      RFB,
-      RFE,
-      BFB,
-      BFE,
-      REAL,
-      REGEX,
-      STRING,
-      LEXICAL,
-      BOOLEAN,
-      INTEGER,
-      RELATIF,
-      QUALIFIED,
-      CHARACTER
-    };
+    enum t_token
+      {
+	ERROR,
+	EOL,
+	EOS,
+	RFB,
+	RFE,
+	BFB,
+	BFE,
+	REAL,
+	REGEX,
+	STRING,
+	LEXICAL,
+	BOOLEAN,
+	INTEGER,
+	RELATIF,
+	COMPLEX,
+	QUALIFIED,
+	CHARACTER
+      };
 
     /// add a new reserved name
     /// @param name the name to add
