@@ -24,10 +24,10 @@ namespace afnix {
   // -------------------------------------------------------------------------
 
   // the nan value
-  static const t_real MTH_NAN_VAL = NAN;
+  static const t_real CV_MTH_XNAN = NAN;
   // the infinite values
-  static const t_real MTH_INF_POS = +INFINITY;
-  static const t_real MTH_INF_NEG = -INFINITY;
+  static const t_real CV_MTH_PINF = +INFINITY;
+  static const t_real CV_MTH_NINF = -INFINITY;
 
   // -------------------------------------------------------------------------
   // - public section                                                       -
@@ -42,7 +42,7 @@ namespace afnix {
   // return the real nan value
   
   t_real c_nan (void) {
-    return MTH_NAN_VAL;
+    return CV_MTH_XNAN;
   }
 
   // return true if the number is infinite
@@ -54,13 +54,13 @@ namespace afnix {
   // return a positive infinite value
   
   t_real c_pinf (void) {
-    return MTH_INF_POS;
+    return CV_MTH_PINF;
   }
 
   // return a positive infinite value
   
   t_real c_ninf (void) {
-    return MTH_INF_NEG;
+    return CV_MTH_NINF;
   }
 
   // return the ceiling of the argument
@@ -150,123 +150,95 @@ namespace afnix {
   // return the tangent of x
  
   t_real c_tan (const t_real x) {
+    if (isinf (x) != 0) return CV_MTH_XNAN;
     return tan (x);
   }
 
   // return the arc sine of the argument
  
-  t_real c_asin (const t_real x, bool& status) {
-    errno  = 0;
-    t_real result = asin (x);
-    if (errno != 0) {
-      status = false;
-      return 0.0;
+  t_real c_asin (const t_real x) {
+    if ((x < -1.0) || (x > 1.0)) {
+      return CV_MTH_XNAN;
     }
-    status = true;
+    t_real result = asin (x);
     return result;
   }
 
   // return the arc cosine of the argument
  
-  t_real c_acos (const t_real x, bool& status) {
-    errno  = 0;
-    t_real result = acos (x);
-    if (errno != 0) {
-      status = false;
-      return 0.0;
+  t_real c_acos (const t_real x) {
+    if ((x < -1.0) || (x > 1.0)) {
+      return CV_MTH_XNAN;
     }
-    status = true;
+    t_real result = acos (x);
     return result;
   }
 
   // return the arc tangent of the argument
  
-  t_real c_atan (const t_real x, bool& status) {
-    errno  = 0;
+  t_real c_atan (const t_real x) {
     t_real result = atan (x);
-    if (errno != 0) {
-      status = false;
-      return 0.0;
-    }
-    status = true;
+    return result;
+  }
+
+  // return the arc tangent two of the argument
+ 
+  t_real c_atan (const t_real x, const t_real y) {
+    t_real result = atan2 (x, y);
     return result;
   }
 
   // return the hyperbolic sine of the argument
  
-  t_real c_sinh (const t_real x, bool& status) {
+  t_real c_sinh (const t_real x) {
     errno  = 0;
     t_real result = sinh (x);
-    if (errno != 0) {
-      status = false;
-      return 0.0;
-    }
-    status = true;
+    if (errno != 0) result = CV_MTH_XNAN;
     return result;
   }
 
   // return the hyperbolic cosine of the argument
  
-  t_real c_cosh (const t_real x, bool& status) {
+  t_real c_cosh (const t_real x) {
     errno  = 0;
     t_real result = cosh (x);
-    if (errno != 0) {
-      status = false;
-      return 0.0;
-    }
-    status = true;
+    if (errno != 0) result = CV_MTH_XNAN;
     return result;
   }
 
   // return the hyperbolic tangent of the argument
  
-  t_real c_tanh (const t_real x, bool& status) {
+  t_real c_tanh (const t_real x) {
     errno  = 0;
     t_real result = tanh (x);
-    if (errno != 0) {
-      status = false;
-      return 0.0;
-    }
-    status = true;
+    if (errno != 0) result = CV_MTH_XNAN;
     return result;
   }
 
   // return the hyperbolic arc sine of the argument
  
-  t_real c_asinh (const t_real x, bool& status) {
+  t_real c_asinh (const t_real x) {
     errno  = 0;
     t_real result = asinh (x);
-    if (errno != 0) {
-      status = false;
-      return 0.0;
-    }
-    status = true;
+    if (errno != 0) result = CV_MTH_XNAN;
     return result;
   }
 
   // return the hyperbolic arc cosine of the argument
  
-  t_real c_acosh (const t_real x, bool& status) {
+  t_real c_acosh (const t_real x) {
     errno  = 0;
     t_real result = acosh (x);
-    if (errno != 0) {
-      status = false;
-      return 0.0;
-    }
-    status = true;
+    if (errno != 0) result = CV_MTH_XNAN;
     return result;
   }
 
   // return the hyperbolic arc tangent of the argument
  
-  t_real c_atanh (const t_real x, bool& status) {
+  t_real c_atanh (const t_real x) {
     errno  = 0;
     t_real result = atanh (x);
-    if (errno != 0) {
-      status = false;
-      return 0.0;
-    }
-    status = true;
+    if (errno != 0) result = CV_MTH_XNAN;
     return result;
   }
 }
