@@ -78,31 +78,34 @@ namespace afnix {
   t_real c_tan (const t_real x);
 
   /// @return the arc sine of the argument
-  t_real c_asin (const t_real x, bool& status);
+  t_real c_asin (const t_real x);
 
   /// @return the arc cosine of the argument in radian
-  t_real c_acos (const t_real x, bool& status);
+  t_real c_acos (const t_real x);
 
-  /// @return the tangent of the argument in radian
-  t_real c_atan (const t_real x, bool& status);
+  /// @return the arc tangent of the argument in radian
+  t_real c_atan (const t_real x);
+
+  /// @return the arc tangent two of the argument in radian
+  t_real c_atan (const t_real x, const t_real y);
 
   /// @return the hyperbolic sine of the argument
-  t_real c_sinh (const t_real x, bool& status);
+  t_real c_sinh (const t_real x);
 
   /// @return the hyperbolic cosine of the argument
-  t_real c_cosh (const t_real x, bool& status);
+  t_real c_cosh (const t_real x);
 
   /// @return the hyperbolic tangent of the argument
-  t_real c_tanh (const t_real x, bool& status);
+  t_real c_tanh (const t_real x);
 
   /// @return the hyperbolic arc sine of the argument
-  t_real c_asinh (const t_real x, bool& status);
+  t_real c_asinh (const t_real x);
 
   /// @return the hyperbolic arc cosine of the argument
-  t_real c_acosh (const t_real x, bool& status);
+  t_real c_acosh (const t_real x);
 
   /// @return the hyperbolic arc tangent of the argument
-  t_real c_atanh (const t_real x, bool& status);
+  t_real c_atanh (const t_real x);
 }
 
 #endif
