@@ -427,7 +427,7 @@ namespace afnix {
     // create an array of capabilities and initialize it
     bool* result = new bool [BTERM_PARMS_MAX];
     // query capabilities
-    result[BTERM_AUTO_WRAP] = c_tigetflag ("am") && c_tigetflag ("xn");
+    result[0] = c_tigetflag ("am") && c_tigetflag ("xn");
     // the array of capabilities
     return result;
   }
