@@ -22,6 +22,7 @@
 #include "QuarkZone.hpp"
 #include "Exception.hpp"
 #include "AliasTable.hpp"
+#include "transient.tcc"
 
 namespace afnix {
 
@@ -45,6 +46,17 @@ namespace afnix {
       }
     }
   }
+
+  // create an alias table by data
+
+  AliasTable::AliasTable (const long size, const String* data) {
+    reset ();
+    if ((size > 0L) && (data != nullptr) && ((size % 2) == 0)) {
+      for (long k = 0L; k < size; k+= 2) {
+	add (data[k], data[k+1]);
+      }
+    }
+  }
   
   // return the class name
 
@@ -186,7 +198,39 @@ namespace afnix {
       throw;
     }
   }
+  
+  // map a hash table by name 
 
+  HashTable AliasTable::map (const HashTable& htbl) const {
+    rdlock ();
+    try {
+      // the hash table result
+      HashTable result;
+      // collect the table keys
+      t_transient<Vector> vkey = htbl.getkeys ();
+      // loop in the key vector
+      long vlen = vkey->length ();
+      for (long k = 0L; k < vlen; k++) {
+	// het the hash key
+	auto hkey = dynamic_cast<String*>(vkey->get (k));
+	// collect the hash object
+	Object* hobj = htbl.get (*hkey);
+	// check for map key
+	auto mkey = dynamic_cast<String*>(d_dtbl.get (*hkey));
+	if (mkey != nullptr) {
+	  result.add (*mkey, hobj);
+	} else {
+	  result.add (*hkey, hobj);
+	}
+      }
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+  
   // map an alias to a name
 
   String AliasTable::remap (const String& name) const {
@@ -227,7 +271,7 @@ namespace afnix {
     }
   }
 
-  // remap a plist by alias name 
+  // remap a plist by alias 
 
   Plist AliasTable::remap (const Plist& plst) const {
     rdlock ();
@@ -249,6 +293,37 @@ namespace afnix {
     }
   }
 
+  // remap a hash table by alias 
+
+  HashTable AliasTable::remap (const HashTable& htbl) const {
+    rdlock ();
+    try {
+      // the hash table result
+      HashTable result;
+      // collect the table keys
+      t_transient<Vector> vkey = htbl.getkeys ();
+      // loop in the key vector
+      for (auto obj : **vkey) {
+	// het the hash key
+	auto hkey = dynamic_cast<String*>(obj);
+	// collect the hash object
+	Object* hobj = htbl.get (*hkey);
+	// check for map key
+	auto mkey = dynamic_cast<String*>(d_rtbl.get (*hkey));
+	if (mkey != nullptr) {
+	  result.add (*mkey, hobj);
+	} else {
+	  result.add (*hkey, hobj);
+	}
+      }
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+  
   // -------------------------------------------------------------------------
   // - object section                                                        -
   // -------------------------------------------------------------------------
@@ -321,14 +396,17 @@ namespace afnix {
       if (quark == QUARK_MAP) {
 	Object* obj = argv->get (0);
 	// check for a string
-	String* sobj = dynamic_cast <String*> (obj);
+	auto sobj = dynamic_cast <String*> (obj);
 	if (sobj != nullptr) return new String (map (*sobj));
 	// check for a property
-	Property* prop = dynamic_cast <Property*> (obj);
+	auto prop = dynamic_cast <Property*> (obj);
 	if (prop != nullptr) return new Property (map (*prop));
 	// check for a plist
-	Plist* plst = dynamic_cast <Plist*> (obj);
+	auto plst = dynamic_cast <Plist*> (obj);
 	if (plst != nullptr) return new Plist (map (*plst));
+	// check for a hash table
+	auto htbl = dynamic_cast <HashTable*> (obj);
+	if (htbl != nullptr) return new HashTable (map (*htbl));
 	// invalid type
 	throw Exception ("type-error", "invalid object with map",
 			 Object::repr (obj));
@@ -336,14 +414,17 @@ namespace afnix {
       if (quark == QUARK_REMAP) {
 	Object* obj = argv->get (0);
 	// check for a string
-	String* sobj = dynamic_cast <String*> (obj);
+	auto sobj = dynamic_cast <String*> (obj);
 	if (sobj != nullptr) return new String (remap (*sobj));
 	// check for a property
-	Property* prop = dynamic_cast <Property*> (obj);
+	auto prop = dynamic_cast <Property*> (obj);
 	if (prop != nullptr) return new Property (remap (*prop));
 	// check for a plist
-	Plist* plst = dynamic_cast <Plist*> (obj);
+	auto plst = dynamic_cast <Plist*> (obj);
 	if (plst != nullptr) return new Plist (remap (*plst));
+	// check for a hash atble
+	auto htbl = dynamic_cast <HashTable*> (obj);
+	if (htbl != nullptr) return new HashTable (remap (*htbl));
 	// invalid type
 	throw Exception ("type-error", "invalid object with remap",
 			 Object::repr (obj));
