@@ -51,6 +51,11 @@ namespace afnix {
     /// @param data the data list
     AliasTable (const long size, const char** data);
     
+    /// create an alias table by data
+    /// @param size the data size
+    /// @param data the data list
+    AliasTable (const long size, const String* data);
+    
     /// @return the class name
     String repr (void) const override;
 
@@ -79,10 +84,14 @@ namespace afnix {
     /// @param prop the property to map
     Property map (const Property& name) const;
 
-    /// map a property list by name
+    /// map a property list by alias
     /// @param plst the property list to map
     Plist map (const Plist& plst) const;
 
+    /// map a hash table by alias
+    /// @param htbl the table to map
+    HashTable map (const HashTable& htbl) const;
+
     /// reverse map an alias to a name
     /// @param name the alias name to remap
     String remap (const String& name) const;
@@ -95,6 +104,10 @@ namespace afnix {
     /// @param plst the property list to remap
     Plist remap (const Plist& plst) const;
 
+    /// reverse map a hash table by alias
+    /// @param htbl the table to remap
+    HashTable remap (const HashTable& htbl) const;
+    
   private:
     // make the copy constructor private
     AliasTable (const AliasTable&);
