@@ -715,6 +715,27 @@ namespace afnix {
     }
   }
 
+  // convert a bitset to a buffer
+
+  Buffer Bitset::tobuffer (const bool rflg) const {
+    rdlock ();
+    try {
+      Buffer result;
+      if (rflg == true) {
+	for (long k = 0L; k < d_bsiz; k++) {
+	  result.add ((char)p_byte[d_bsiz-k-1]);
+	}
+      } else {
+	result.add ((char*) p_byte, d_bsiz);
+      }
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+  
   // map this buffer to an anonymous data structure
 
   long Bitset::tomap (void* data, const long size) const {
