@@ -161,6 +161,10 @@ namespace afnix {
     /// convert a bitset to a relatif
     Relatif torelatif (void) const;
 
+    /// convert a bitset to a buffer
+    /// @param rflg the reverse flag
+    Buffer tobuffer (const bool rflg) const;
+    
     /// map this bitset to an anonymous data structure
     /// @param data the data structure to map
     /// @param size the data size to map
