@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2020 amaury darsch                                   -
+// - copyright (c) 1999-2021 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Byte.hpp"
@@ -1032,7 +1032,45 @@ namespace afnix {
       throw;
     }
   }
+
+  // move the buffer content into another one
   
+  Buffer Buffer::move (const long size) {
+    // lock and copy
+    wrlock ();
+    try {
+      // check valid argument
+      if (size <= 0L) {
+	throw Exception ("buffer-error", "invalid buffer size to move");
+      }
+      // initialize result
+      long blen = (size <= d_blen) ? size : d_blen;
+      // create target buffer and move
+      Buffer result (size);
+      // copy by loop
+      for (long k = 0L; k < blen; k++) result.p_data[k] = p_data[k + d_ridx];
+      // nullify the rest of the buffer
+      if (size > blen) {
+        for (long k = blen; k < size; k++) result.p_data[k] = nilc;
+      }
+      // adjust buffer content and size
+      if (blen < d_blen) {
+	d_ridx += blen;
+	d_blen -= blen;
+      } else {
+	d_blen = 0L;
+	d_ridx = 0L;
+      }
+      result.d_blen = size;
+      // done
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+
   // shift the buffer by a certain amount
 
   void Buffer::shl (const long asl) {
@@ -1276,14 +1314,13 @@ namespace afnix {
       Buffer result (size);
       // copy in the result buffer
       for (long k = 0L; k < blen; k++) {
-	result.p_data[k] = p_data[k + d_ridx];
+	result.p_data[k] = p_data[d_blen + d_ridx - blen + k];
       }
       // nullify the rest of the buffer
       if (size > blen) {
 	for (long k = blen; k < size; k++) result.p_data[k] = nilc;
       }
       // update the local buffer
-      d_ridx += blen;
       d_blen -= blen;
       // update the result buffer
       result.d_blen = size;
@@ -1294,7 +1331,7 @@ namespace afnix {
       throw;
     }
   }
-  
+
   // extract a buffer by position and size
 
   Buffer Buffer::extract (const long boff, const long size) const {
@@ -1541,6 +1578,7 @@ namespace afnix {
   static const long QUARK_GET      = zone.intern ("get");
   static const long QUARK_SHL      = zone.intern ("shl");
   static const long QUARK_READ     = zone.intern ("read");
+  static const long QUARK_MOVE     = zone.intern ("move");
   static const long QUARK_RESET    = zone.intern ("reset");
   static const long QUARK_READW    = zone.intern ("read-word");
   static const long QUARK_READQ    = zone.intern ("read-quad");
@@ -1564,17 +1602,23 @@ namespace afnix {
     long argc = (argv == nullptr) ? 0 : argv->length ();
     // create an empty buffer with 0 arguments
     Buffer* result = new Buffer;
-    // loop with literal objects
+    // loop with objects
     for (long i = 0; i < argc; i++) {
       Object* obj = argv->get (i);
+      // check for a viewable
+      auto wobj = dynamic_cast <Viewable*> (obj);
+      if (wobj != nullptr) {
+	result->add ((const char*) wobj->tobyte(), wobj->tosize ());
+	continue;
+      }
       // check for a literal
-      Literal* lobj = dynamic_cast <Literal*> (obj);
+      auto lobj = dynamic_cast <Literal*> (obj);
       if (lobj != nullptr) {
 	result->add (lobj->tostring ());
 	continue;
       }
       // check for a vector
-      Vector* vobj = dynamic_cast <Vector*> (obj);
+      auto vobj = dynamic_cast <Vector*> (obj);
       if (vobj != nullptr) {
 	long vlen = vobj->length ();
 	for (long j = 0; j < vlen; j++) {
@@ -1652,48 +1696,64 @@ namespace afnix {
 	setrflg (rflg);
 	return nullptr;
       }
+      if (quark == QUARK_MOVE) {
+	long size = argv->getlong (0);
+	return new Buffer (move (size));
+      }
       if (quark == QUARK_ADD) {
 	Object* obj = argv->get (0);
 	// check for a byte
-	Byte* bobj = dynamic_cast<Byte*> (obj);
+	auto bobj = dynamic_cast<Byte*> (obj);
 	if (bobj != nullptr) {
 	  long result = add ((char) bobj->tobyte ());
 	  return new Integer (result);
 	}
-	// check for a literal
-	Literal* lobj = dynamic_cast<Literal*> (obj);
-	if (lobj != nullptr) {
-	  long result = add (lobj->tostring ());
-	  return new Integer (result);
-	}
 	// check for a buffer
-	Buffer* uobj = dynamic_cast<Buffer*> (obj);
+	auto uobj = dynamic_cast<Buffer*> (obj);
 	if (uobj != nullptr) {
 	  long result = add (*uobj);
 	  return new Integer (result);
 	}
+	// check for a viewable
+	auto wobj = dynamic_cast<Viewable*> (obj);
+	if (wobj != nullptr) {
+	  long result = add ((char*) wobj->tobyte (), wobj->tosize ());
+	  return new Integer (result);
+	}
+	// check for a literal
+	auto lobj = dynamic_cast<Literal*> (obj);
+	if (lobj != nullptr) {
+	  long result = add (lobj->tostring ());
+	  return new Integer (result);
+	}
 	throw Exception ("type-error", "invalid object to add in buffer");
       }
       if (quark == QUARK_PUSHBACK) {
 	Object* obj = argv->get (0);
 	// check for a byte
-	Byte* bobj = dynamic_cast<Byte*> (obj);
+	auto bobj = dynamic_cast<Byte*> (obj);
 	if (bobj != nullptr) {
 	  long result = pushback ((char) bobj->tobyte ());
 	  return new Integer (result);
 	}
-	// check for a literal
-	Literal* lobj = dynamic_cast<Literal*> (obj);
-	if (lobj != nullptr) {
-	  long result = pushback (lobj->tostring ());
-	  return new Integer (result);
-	}
 	// check for a buffer
-	Buffer* uobj = dynamic_cast<Buffer*> (obj);
+	auto uobj = dynamic_cast<Buffer*> (obj);
 	if (uobj != nullptr) {
 	  long result = pushback (*uobj);
 	  return new Integer (result);
 	}
+	// check for a viewable
+	auto wobj = dynamic_cast<Viewable*> (obj);
+	if (wobj != nullptr) {
+	  long result = pushback ((char*) wobj->tobyte (), wobj->tosize());
+	  return new Integer (result);
+	}
+	// check for a literal
+	auto lobj = dynamic_cast<Literal*> (obj);
+	if (lobj != nullptr) {
+	  long result = pushback (lobj->tostring ());
+	  return new Integer (result);
+	}
 	throw Exception ("type-error", "invalid object to pushback in buffer");
       }
       if (quark == QUARK_COLLECT) {
