@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2020 amaury darsch                                   -
+// - copyright (c) 1999-2021 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Stdsid.hxx"
@@ -716,28 +716,29 @@ namespace afnix {
     Integer*   iobj = dynamic_cast <Integer*>   (object);
     Character* cobj = dynamic_cast <Character*> (object);
     switch (type) {
-    case Object::ADD:
+    case Object::OPER_ADD:
       if (iobj != nullptr) return new Character (*this + iobj->tolong ());
       break;
-    case Object::SUB:
+    case Object::OPER_SUB:
       if (iobj != nullptr) return new Character (*this - iobj->tolong ());
       break;
-    case Object::EQL:
+    case Object::OPER_EQL:
+    case Object::OPER_QEQ:
       if (cobj != nullptr) return new Boolean (*this == *cobj);
       break;
-    case Object::NEQ:
+    case Object::OPER_NEQ:
       if (cobj != nullptr) return new Boolean (*this != *cobj);
       break;
-    case Object::GEQ:
+    case Object::OPER_GEQ:
       if (cobj != nullptr) return new Boolean (*this >= *cobj);
       break;
-    case Object::GTH:
+    case Object::OPER_GTH:
       if (cobj != nullptr) return new Boolean (*this > *cobj);
       break;
-    case Object::LEQ:
+    case Object::OPER_LEQ:
       if (cobj != nullptr) return new Boolean (*this <= *cobj);
       break;
-    case Object::LTH:
+    case Object::OPER_LTH:
       if (cobj != nullptr) return new Boolean (*this < *cobj);
       break;
     default:
@@ -812,14 +813,14 @@ namespace afnix {
     }
     // dispatch 1 argument
     if (argc == 1) {
-      if (quark == QUARK_ADD) return oper (Object::ADD, argv->get (0));
-      if (quark == QUARK_SUB) return oper (Object::SUB, argv->get (0));
-      if (quark == QUARK_EQL) return oper (Object::EQL, argv->get (0));
-      if (quark == QUARK_NEQ) return oper (Object::NEQ, argv->get (0));
-      if (quark == QUARK_LTH) return oper (Object::LTH, argv->get (0));
-      if (quark == QUARK_LEQ) return oper (Object::LEQ, argv->get (0));
-      if (quark == QUARK_GTH) return oper (Object::GTH, argv->get (0));
-      if (quark == QUARK_GEQ) return oper (Object::GEQ, argv->get (0));
+      if (quark == QUARK_ADD) return oper (Object::OPER_ADD, argv->get (0));
+      if (quark == QUARK_SUB) return oper (Object::OPER_SUB, argv->get (0));
+      if (quark == QUARK_EQL) return oper (Object::OPER_EQL, argv->get (0));
+      if (quark == QUARK_NEQ) return oper (Object::OPER_NEQ, argv->get (0));
+      if (quark == QUARK_LTH) return oper (Object::OPER_LTH, argv->get (0));
+      if (quark == QUARK_LEQ) return oper (Object::OPER_LEQ, argv->get (0));
+      if (quark == QUARK_GTH) return oper (Object::OPER_GTH, argv->get (0));
+      if (quark == QUARK_GEQ) return oper (Object::OPER_GEQ, argv->get (0));
 
       if (quark == QUARK_AEQ) {
 	wrlock ();
