@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2020 amaury darsch                                   -
+// - copyright (c) 1999-2021 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_CODEC_HPP
@@ -42,10 +42,10 @@ namespace afnix {
     String  d_name;
     /// the reverse flag
     bool    d_rflg;
-    /// the cumulative read
-    long    d_rnum;
-    /// the cumulative write
-    long    d_wnum;
+    /// the encode stats
+    long    d_encs[2];
+    /// the decode stats
+    long    d_decs[2];
 
   public:
     /// create a default codec
