@@ -27,14 +27,29 @@ namespace afnix {
 
   // copy move this comparable
 
-  Comparable::Comparable (Comparable&& that) noexcept :
-    Object (static_cast<Object&&>(that)) {
+  Comparable::Comparable (Comparable&& that) noexcept {
+    that.wrlock ();
+    try {
+      Object::operator = (static_cast<Object&&>(that));
+    } catch (...) {
+    }
+    that.unlock ();
   }
   
   // move this comparable into this one
 
   Comparable& Comparable::operator = (Comparable&& that) noexcept {
-    Object::operator = (static_cast<Object&&>(that));
+    // check for self assignation
+    if (this == &that) return *this;
+    // lock and assign
+    wrlock ();
+    that.wrlock ();
+    try {
+      Object::operator = (static_cast<Object&&>(that));
+    } catch (...) {
+    }
+    unlock ();
+    that.unlock ();
     return *this;
   }
 
