@@ -11,11 +11,12 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2020 amaury darsch                                   -
+// - copyright (c) 1999-2021 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Date.hpp"
 #include "Regex.hpp"
+#include "Strvec.hpp"
 #include "Vector.hpp"
 #include "Integer.hpp"
 #include "Utility.hpp"
@@ -547,7 +548,9 @@ namespace afnix {
 
   // create a current date
 
-  Date::Date (void) {}
+  Date::Date (void) {
+    setdate (Time::TNOW);
+  }
 
   // create a specific date
 
@@ -708,14 +711,53 @@ namespace afnix {
       throw;
     } 
   }
-
+  
+  // format the date in the extended form
+  
+  String Date::toext (const bool utc) const {
+    rdlock ();
+    try {
+      // format the date
+      String result = todate (utc);
+      // format the time
+      result += 'T';
+      result += Time::toext (utc);
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+  
   // set a date by an iso specification
 
   void Date::setdate (const String& date) {
     wrlock ();
     try {
+      // check for now
+      if (date == Time::TNOW) {
+	Time::settime (Time::TNOW);
+	unlock ();
+	return;
+      }
+      // check for zulu time
+      if (date.last () != 'Z') {
+	throw Exception ("date-error", "missing zulu date postfix", date);
+      }
+      // split date and extended clock
+      String sdat = date;
+      Strvec svec = Strvec::split (date, ".");
+      if (svec.length () > 2) {
+	throw Exception ("time-error", "invalid date string", date);
+      }
+      if (svec.length () == 2) {
+	sdat = svec.get (0) + "Z";
+	String eclk = svec.get (1); eclk = eclk.lsubstr (eclk.length()-1);
+	d_eclk = Utility::toreal (String (".") + eclk);
+      }
       // extract the atc time
-      t_long tclk = atc_time_from_date (date);
+      t_long tclk = atc_time_from_date (sdat);
       // set the time
       settime (tclk);
       // unlock and return
