@@ -21,15 +21,10 @@
 #include "Evaluable.hpp"
 #include "QuarkZone.hpp"
 #include "Exception.hpp"
+#include "fifo.tcc"
 
 namespace afnix {
 
-  // -------------------------------------------------------------------------
-  // - private section                                                       -
-  // -------------------------------------------------------------------------
-
-  static const long DEF_FIFO_SIZE = 64;
-
   // -------------------------------------------------------------------------
   // - class section                                                         -
   // -------------------------------------------------------------------------
@@ -37,17 +32,13 @@ namespace afnix {
   // create a new fifo
   
   Fifo::Fifo (void) {
-    d_size = DEF_FIFO_SIZE;
-    p_fifo = new Object*[d_size];
-    for (long i = 0; i < d_size; i++) p_fifo[i] = nullptr;
+    p_fifo = new t_fifo<Object*>;
   }
   
   // create a new fifo by size
   
   Fifo::Fifo (const long size) {
-    d_size = (size > 0) ? size : DEF_FIFO_SIZE;
-    p_fifo = new Object*[d_size];
-    for (long i = 0; i < d_size; i++) p_fifo[i] = nullptr;
+    p_fifo = new t_fifo<Object*>(size);
   }
 
   // copy construct this fifo
@@ -55,10 +46,12 @@ namespace afnix {
   Fifo::Fifo (const Fifo& that) {
     that.rdlock ();
     try {
-      d_size = that.d_size;
-      p_fifo = new Object*[d_size];
-      for (long i = 0; i < d_size; i++) {
-	Object::iref (p_fifo[i] = that.p_fifo[i]);
+      // allocate the fifo
+      p_fifo = new t_fifo<Object*>;
+      // copy by getter
+      long flen = that.p_fifo->length (); p_fifo->resize (flen);
+      for (long k = 0L; k < flen; k++) {
+	p_fifo->push (Object::iref (that.p_fifo->get(k)));
       }
       that.unlock ();
     } catch (...) {
@@ -70,8 +63,8 @@ namespace afnix {
   // destroy this fifo
 
   Fifo::~Fifo (void) {
-    for (long i = 0; i < d_size; i++) Object::dref (p_fifo[i]);
-    delete [] p_fifo;
+    while (p_fifo->empty() == false) Object::dref (p_fifo->pop ());
+    delete p_fifo;
   }
 
   // return the class name
@@ -90,13 +83,14 @@ namespace afnix {
     that.rdlock ();
     try {
       // remove the old fifo
-      for (long i = 0; i < d_size; i++) Object::dref (p_fifo[i]);
-      delete [] p_fifo; p_fifo = nullptr;
-      // create a new fifo
-      d_size = that.d_size;
-      p_fifo = new Object*[d_size];
-      for (long i = 0; i < d_size; i++) {
-	Object::iref (p_fifo[i] = that.p_fifo[i]);
+      while (p_fifo->empty() == false) Object::dref (p_fifo->pop());
+      delete p_fifo; p_fifo = nullptr;
+      // allocate the fifo
+      p_fifo = new t_fifo<Object*>;
+      // copy by getter
+      long flen = that.p_fifo->length (); p_fifo->resize (flen);
+      for (long k = 0L; k < flen; k++) {
+	p_fifo->push (Object::iref (that.p_fifo->get(k)));
       }
       // unlock and return
       unlock ();
@@ -114,10 +108,8 @@ namespace afnix {
   void Fifo::reset (void) {
     wrlock ();
     try {
-      for (long i = 0; i < d_size; i++) {
-	Object::dref (p_fifo[i]);
-	p_fifo[i] = nullptr;
-      }
+      while (p_fifo->empty() == false) Object::dref (p_fifo->pop());
+      p_fifo->reset ();
       unlock ();
     } catch (...) {
       unlock ();
@@ -130,7 +122,7 @@ namespace afnix {
   long Fifo::getsize (void) const {
     rdlock ();
     try {
-      long result = d_size;
+      long result = p_fifo->getsize ();
       unlock ();
       return result;
     } catch (...) {
@@ -144,11 +136,7 @@ namespace afnix {
   long Fifo::length (void) const {
     rdlock ();
     try {
-      long result = 0;
-      for (long i = 0; i < d_size; i++) {
-	if (p_fifo[i] == nullptr) break;
-	result++;
-      }
+      long result = p_fifo->length ();
       unlock ();
       return result;
     } catch (...) {
@@ -162,7 +150,7 @@ namespace afnix {
   bool Fifo::empty (void) const {
     rdlock ();
     try {
-      bool result = (p_fifo[0] == nullptr);
+      bool result = p_fifo->empty ();
       unlock ();
       return result;
     } catch (...) {
@@ -176,7 +164,7 @@ namespace afnix {
   bool Fifo::full (void) const {
     rdlock ();
     try {
-      bool result = (p_fifo[d_size-1] != nullptr);
+      bool result = p_fifo->full ();
       unlock ();
       return result;
     } catch (...) {
@@ -188,18 +176,15 @@ namespace afnix {
   // push an object into the fifo
 
   void Fifo::push (Object* obj) {
-    // do nothing if nil
-    if (obj == nullptr) return;
     // lock and push
     wrlock ();
     try {
-      // clean the last element
-      Object::dref (p_fifo[d_size-1]);
-      // shift by one position
-      for (long i = d_size-1; i > 0; i--) p_fifo[i] = p_fifo[i-1];
+      // check for full (but not empty ah ah)
+      if ((p_fifo->empty() == false) && (p_fifo->full () == true)) {
+	Object::dref (p_fifo->pop ());
+      }
       // push the object
-      Object::iref (p_fifo[0] = obj);
-      // unlock and return 
+      p_fifo->push (Object::iref (obj));
       unlock ();
     } catch (...) {
       unlock ();
@@ -212,13 +197,12 @@ namespace afnix {
   Object* Fifo::pop (void) {
     wrlock ();
     try {
-      // save the object result
-      Object* result = p_fifo[0];
-      // shift the object
-      for (long i = 1; i < d_size; i++) p_fifo[i-1] = p_fifo[i];
-      // clean the last position
-      p_fifo[d_size-1] = nullptr;
-      // unlock and return
+      // check for empty
+      if (p_fifo->empty () == true) {
+	unlock ();
+	return nullptr;
+      }
+      Object* result = p_fifo->pop ();
       Object::tref (result);
       unlock ();
       return result;
@@ -234,11 +218,11 @@ namespace afnix {
     rdlock ();
     try {
       // check that we are bounded
-      if ((index < 0) || (index >= d_size)) {
+      if ((index < 0) || (index >= p_fifo->length ())) {
 	throw Exception ("index-error","fifo index is out of range");
       }
       // get the object and unlock
-      Object* result = p_fifo[index];
+      Object* result = p_fifo->get (index);
       unlock ();
       return result;
     } catch (...) {
@@ -252,33 +236,7 @@ namespace afnix {
   void Fifo::resize (const long size) {
     wrlock ();
     try {
-      // do nothing with same size
-      if (size == d_size) {
-	unlock ();
-	return;
-      }
-      // check the new size
-      if (size <= 0) {
-	throw Exception ("fifo-error","invalid size during resize operation");
-      }
-      // create a new fifo
-      Object** fifo = new Object*[size];
-      for (long i = 0; i < size; i++) fifo[i] = nullptr;
-      // check for reduction
-      if (size < d_size) {
-	for (long i = 0; i < size; i++) fifo[i] = p_fifo[i];
-	for (long i = size; i < d_size; i++) Object::dref (p_fifo[i]);
-      }
-      // check for expansion
-      if (d_size < size) {
-	for (long i = 0; i < d_size; i++) fifo[i] = p_fifo[i];
-      }
-      // clean the old fifo arry
-      delete [] p_fifo;
-      // update with new fifo
-      d_size = size;
-      p_fifo = fifo;
-      // unlock and return
+      p_fifo->resize (size);
       unlock ();	
     } catch (...) {
       unlock ();
