@@ -17,6 +17,10 @@
 #ifndef  AFNIX_FIFO_HPP
 #define  AFNIX_FIFO_HPP
 
+#ifndef  AFNIX_BITS_HPP
+#include "Bits.hpp"
+#endif
+
 #ifndef  AFNIX_STRING_HPP
 #include "String.hpp"
 #endif
@@ -25,19 +29,15 @@ namespace afnix {
 
   /// The Fifo class is yet another container that provides the implementation
   /// for a fixed size fifo. Unlink the vector object, the fifo is not self
-  /// resizable although the object can be resized manually. The objects are
-  /// added into the first position after shifting the internal structure.
-  /// If the fifo is full, adding element into the fifo will result in loosing
-  /// the oldest object although the fifo can be resized prior this operation.
-  /// The default size for the fifo is 64 elements.
+  /// resizable although the object can be resized manually. By default, a
+  /// drop policy is implemented for full fifo. The default size for the fifo
+  /// is 64 objects.
   /// @author amaury darsch
 
   class Fifo : public virtual Object {
   private:
-    /// the fifo size
-    long     d_size;
-    /// the fifo array
-    Object** p_fifo;
+    /// the object fifo
+    t_fifo<Object*>* p_fifo;
 
   public:
     /// create a default fifo
