@@ -78,8 +78,8 @@ namespace afnix {
   // bucket if it is found and maintain the link list.
   static inline s_bucket* rmbucket (s_bucket**   root, 
 				    const String& key, const bool cifg) {
-    s_bucket* bucket = *root;
-    // simple check as fast as we can
+    // map root bucket
+    s_bucket* bucket = (root == nullptr) ? nullptr : *root;
     if (bucket == nullptr) return nullptr;
     // first case for the root bucket
     if ((bucket->d_key == key) ||
@@ -121,29 +121,21 @@ namespace afnix {
   // create a new hash table
   
   HashTable::HashTable (void) {
-    // build the array
-    d_size = Prime::mkthrp (0);
-    d_hlen = 0;
-    d_thrs = (d_size * 7) / 10;
+    d_size = 0L;
+    d_hlen = 0L;
+    d_thrs = 0L;
     d_cifg = false;
-    p_htbl = new s_bucket*[d_size];
-    // initialize the table with null pointers
-    for (long i = 0; i < d_size; i++)
-      p_htbl[i] = nullptr;
+    p_htbl = nullptr;
   }
   
   // create a new hash table by case flag
   
   HashTable::HashTable (const bool cifg) {
-    // build the array
-    d_size = Prime::mkthrp (0);
-    d_hlen = 0;
-    d_thrs = (d_size * 7) / 10;
+    d_size = 0L;
+    d_hlen = 0L;
+    d_thrs = 0L;
     d_cifg = cifg;
-    p_htbl = new s_bucket*[d_size];
-    // initialize the table with null pointers
-    for (long i = 0; i < d_size; i++)
-      p_htbl[i] = nullptr;
+    p_htbl = nullptr;
   }
 
   // create a new hash table with a predefined size
@@ -156,8 +148,7 @@ namespace afnix {
     d_cifg = false;
     p_htbl = new s_bucket*[d_size];
     // initialize the table with null pointers
-    for (long i = 0; i < d_size; i++)
-      p_htbl[i] = nullptr;
+    for (long k = 0L; k < d_size; k++) p_htbl[k] = nullptr;
   }
 
   // create a new hash table by size and case flag
@@ -170,25 +161,157 @@ namespace afnix {
     d_cifg = cifg;
     p_htbl = new s_bucket*[d_size];
     // initialize the table with null pointers
-    for (long i = 0; i < d_size; i++)
-      p_htbl[i] = nullptr;
+    for (long k = 0L; k < d_size; k++) p_htbl[k] = nullptr;
+  }
+
+  // copy construct this hash table
+
+  HashTable::HashTable (const HashTable& that) {
+    that.rdlock ();
+    try {
+      d_size = that.d_size;
+      d_hlen = 0L;
+      d_thrs = that.d_thrs;
+      d_cifg = that.d_cifg;
+      p_htbl = nullptr;
+      if (d_size > 0L) {
+	p_htbl = new s_bucket*[d_size];
+	// initialize the table with null pointers
+	for (long k = 0L; k < d_size; k++) p_htbl[k] = nullptr;
+	// loop in the bucket
+	for (long k = 0L; k < d_size; k++) {
+	  s_bucket* bucket = that.p_htbl[k];
+	  while (bucket != nullptr) {
+	    add (bucket->d_key, bucket->p_obj);
+	    bucket = bucket->p_next;
+	  }
+	}
+      }
+      that.unlock ();
+    } catch (...) {
+      that.unlock ();
+      throw;
+    }
+  }
+
+  // copy move this hash table
+
+  HashTable::HashTable (HashTable&& that) noexcept {
+    that.wrlock ();
+    try {
+      // move base serial
+      Serial::operator = (static_cast<Serial&&>(that));
+      // copy move locally
+      d_size = that.d_size; that.d_size = 0L;
+      d_hlen = that.d_hlen; that.d_hlen = 0L;
+      d_thrs = that.d_thrs; that.d_thrs = 0L;
+      d_cifg = that.d_cifg; that.d_cifg = false;
+      p_htbl = that.p_htbl; that.p_htbl = nullptr; 
+      that.unlock ();
+    } catch (...) {
+      that.d_size = 0L;
+      that.d_hlen = 0L;
+      that.d_thrs = 0L;
+      that.d_cifg = false;
+      that.p_htbl = nullptr; 
+      that.unlock ();
+    }
   }
   
   // delete this hash table 
   
   HashTable::~HashTable (void) {
     if (p_htbl != nullptr) {
-      for (long i = 0; i < d_size; i++) delete p_htbl[i];
+      for (long k = 0L; k < d_size; k++) delete p_htbl[k];
       delete [] p_htbl;
     }
   }
 
+  // assign a hash table to this one
+
+  HashTable& HashTable::operator = (const HashTable& that) {
+    // check for self assignation
+    if (this == &that) return *this;
+    // lock and assign
+    wrlock ();
+    that.rdlock ();
+    try {
+      // clean old table
+      reset ();
+      delete [] p_htbl; p_htbl = nullptr;
+      // assign new table
+      d_size = that.d_size;
+      d_hlen = 0L;
+      d_thrs = that.d_thrs;
+      d_cifg = that.d_cifg;
+      p_htbl = nullptr;
+      if (d_size > 0L) {
+	p_htbl = new s_bucket*[d_size];
+	// initialize the table with null pointers
+	for (long k = 0L; k < d_size; k++) p_htbl[k] = nullptr;
+	// loop in the bucket
+	for (long k = 0L; k < d_size; k++) {
+	  s_bucket* bucket = that.p_htbl[k];
+	  while (bucket != nullptr) {
+	    add (bucket->d_key, bucket->p_obj);
+	    bucket = bucket->p_next;
+	  }
+	}
+      }
+      unlock ();
+      that.unlock ();
+      return *this;
+    } catch (...) {
+      that.unlock ();
+      throw;
+    }
+  }
+
+  // move a hash table into this one
+
+  HashTable& HashTable::operator = (HashTable&& that) noexcept {
+    // check for self-move
+    if (this == &that) return *this;
+    // lock everybody
+    wrlock ();
+    that.wrlock ();
+    try {
+      // reset locally
+      reset ();
+      // assign base serial
+      Serial::operator = (static_cast<Serial&&>(that));
+      // move locally
+      d_size = that.d_size; that.d_size = 0L;
+      d_hlen = that.d_hlen; that.d_hlen = 0L;
+      d_thrs = that.d_thrs; that.d_thrs = 0L;
+      d_cifg = that.d_cifg; that.d_cifg = false;
+      p_htbl = that.p_htbl; that.p_htbl = nullptr; 
+      unlock ();
+      that.unlock ();
+    } catch (...) {
+      that.d_size = 0L;
+      that.d_hlen = 0L;
+      that.d_thrs = 0L;
+      that.d_cifg = false;
+      that.p_htbl = nullptr; 
+      unlock ();
+      that.unlock ();
+    }
+    return *this;
+  }
+  
   // return the class name
 
   String HashTable::repr (void) const {
     return "HashTable";
   }
+  
+  // get a clone of this object
 
+  Object* HashTable::clone (void) const {
+    return new HashTable (*this);
+  }
+  
   // return the hash table did
 
   t_word HashTable::getdid (void) const {
@@ -207,22 +330,30 @@ namespace afnix {
     rdlock ();
     try {
       // write the table length
-      Serial::wrlong (d_hlen, os);
-      // write the name/objects
-      for (long k = 0L; k < d_hlen; k++) {
-	String name = getkey(k); name.wrstream(os);
-	Object* obj = getobj (k);
-	if (obj == nullptr) {
-	  Serial::wrnilid (os);
-	} else {
-	  Serial* sobj = dynamic_cast <Serial*> (obj);
-	  if (sobj == nullptr) {
-	    throw Exception ("serial-error", "cannot serialize object", 
-			     obj->repr ());
+      Serial::wrlong (d_hlen, os); long hcnt = 0L;
+      // loop in the bucket
+      for (long k = 0L; k < d_size; k++) {
+	s_bucket* bucket = p_htbl[k];
+	while (bucket != nullptr) {
+	  bucket->d_key.wrstream (os);
+	  if (bucket->p_obj == nullptr) {
+	    Serial::wrnilid (os);
+	  } else {
+	    Serial* sobj = dynamic_cast <Serial*> (bucket->p_obj);
+	    if (sobj == nullptr) {
+	      throw Exception ("hash-error", "cannot serialize object",
+			       Object::repr (bucket->p_obj));
+	    }
+	    sobj->serialize (os);
 	  }
-	  sobj->serialize (os);
+	  hcnt++;
+	  bucket = bucket->p_next;
 	}
       }
+      // paranoid vereification
+      if (hcnt != d_hlen) {
+	throw Exception ("hash-error", "inconsistent hash table count");
+      }
       unlock ();
     } catch (...) {
       unlock ();
@@ -348,7 +479,7 @@ namespace afnix {
 	  bucket = bucket->p_next;
 	}
       }
-      throw Exception ("index-error", "index is out of range");
+      throw Exception ("hash-error", "index is out of range");
     } catch (...) {
       unlock ();
       throw;
@@ -373,7 +504,7 @@ namespace afnix {
 	  bucket = bucket->p_next;
 	}
       }
-      throw Exception ("index-error", "index is out of range");
+      throw Exception ("hash-error", "index is out of range");
     } catch (...) {
       unlock ();
       throw;
@@ -385,6 +516,11 @@ namespace afnix {
   bool HashTable::exists (const String& key) const {
     rdlock ();
     try {
+      // check for null size
+      if (d_size == 0L) {
+	unlock ();
+	return false;
+      }
       // compute hash id
       long hvl = d_cifg ? key.tolower().hashid () : key.hashid ();
       long hid = hvl % d_size;
@@ -404,6 +540,8 @@ namespace afnix {
   void HashTable::add (const String& key, Object* object) {
     wrlock ();
     try {
+      // check for resize
+      if (d_size == 0L) resize (0);
       // protect the object
       Object::iref (object);
       // compute the hash value
@@ -432,11 +570,16 @@ namespace afnix {
     }
   }
   
-  // get an object by key. If the key is not found, nullptr is returned
+  // get an object by key
   
   Object* HashTable::get (const String& key) const {
     rdlock ();
     try {
+      // check for null size
+      if (d_size == 0L) {
+	unlock ();
+	return nullptr;
+      }
       // compute hash id
       long hvl = d_cifg ? key.tolower().hashid () : key.hashid ();
       long hid = hvl % d_size;
@@ -451,11 +594,15 @@ namespace afnix {
     }
   }
 
-  // get an object by key. If the key is not found an exception is raised
+  // get an object by key or throw an exception
 
   Object* HashTable::lookup (const String& key) const {
     rdlock ();
     try {
+      // check for null size
+      if (d_size == 0L) {
+	throw Exception ("hash-error", "key not found", key);
+      }	
       // compute hash id
       long hvl = d_cifg ? key.tolower().hashid () : key.hashid ();
       long hid = hvl % d_size;
@@ -466,7 +613,7 @@ namespace afnix {
 	unlock ();
 	return result;
       }
-      throw Exception ("key-error", "key not found", key);
+      throw Exception ("hash-error", "key not found", key);
     } catch (...) {
       unlock ();
       throw;
@@ -478,6 +625,11 @@ namespace afnix {
   void HashTable::remove (const String& key) {
     wrlock ();
     try {
+      // check for nil size
+      if (d_size == 0L) {
+	unlock ();
+	return;
+      }
       // compute hash id
       long hvl = d_cifg ? key.tolower().hashid () : key.hashid ();
       long hid = hvl % d_size;   
@@ -493,7 +645,7 @@ namespace afnix {
       throw;
     }
   }
-  
+
   // return a vector of keys in this hash table
 
   Vector* HashTable::getkeys (void) const {
@@ -521,8 +673,8 @@ namespace afnix {
     rdlock ();
     try {
       Vector* result = new Vector;
-      for (long i = 0; i < d_size; i++) {
-	s_bucket* bucket = p_htbl[i];
+      for (long k = 0L; k < d_size; k++) {
+	s_bucket* bucket = p_htbl[k];
 	while (bucket != nullptr) {
 	  Object* obj = bucket->p_obj;
 	  if (obj != nullptr) result->add (obj);
@@ -542,8 +694,21 @@ namespace afnix {
   void HashTable::resize (const long size) {
     wrlock ();
     try {
+      // special initial case
+      if ((size == 0L) && (d_size == 0L)) {
+	// build the array
+	d_size = Prime::mkthrp (0);
+	d_hlen = 0;
+	d_thrs = (d_size * 7) / 10;
+	p_htbl = new s_bucket*[d_size];
+	// initialize the table with null pointers
+	for (long i = 0; i < d_size; i++) p_htbl[i] = nullptr;
+      }
       // check for the size
-      if (size < d_size) return;
+      if (size < d_size) {
+	unlock ();
+	return;
+      }
       // initialize the new table
       s_bucket** table = new s_bucket*[size];
       for (long i = 0; i < size; i++) table[i] = nullptr;
