@@ -104,9 +104,9 @@ namespace afnix {
     
   private:
     // make the copy constructor private
-    InputMapped (const InputMapped&);
+    InputMapped (const InputMapped&) =delete;
     // make the assignment operator private
-    InputMapped& operator = (const InputMapped&);
+    InputMapped& operator = (const InputMapped&) =delete;
 
   public:
     /// create a new object in a generic way
