@@ -334,7 +334,7 @@ namespace afnix {
     wrlock ();
     try {
       // create a buffer to accumulate characters
-      Buffer buf;
+      Buffer buf (d_emod);
       bool   flg = false;
       // read the character in the buffer
       while (valid () == true) {
