@@ -36,18 +36,23 @@ namespace afnix {
   // create an empty string stream
 
   InputString::InputString (void)  {
-    d_sbuf.setemod (Encoding::EMOD_UTF8);
     setemod (Encoding::EMOD_UTF8);
   }
 
-  // create a string stream with a buffer
+  // create a string stream by string
 
   InputString::InputString (const String& data)  {
-    d_sbuf.setemod (Encoding::EMOD_UTF8);
     setemod (Encoding::EMOD_UTF8);
     d_sbuf.pushback (data);
   }
 
+  // create a string stream by buffer
+
+  InputString::InputString (const Buffer& sbuf)  {
+    setemod (Encoding::EMOD_UTF8);
+    d_sbuf.pushback (sbuf);
+  }
+
   // return the class name
 
   String InputString::repr (void) const {
@@ -158,11 +163,19 @@ namespace afnix {
 
     // check for 0 argument
     if (argc == 0) return new InputString;
-
     // check for 1 argument
     if (argc == 1) {
-      String sval = argv->getstring (0);
-      return new InputString (sval);
+      // get the objet and check
+      Object* obj = argv->get (0);
+      // check for a string
+      auto sval = dynamic_cast<String*>(obj);
+      if (sval != nullptr) return new InputString (*sval);
+      // check for a buffer
+      auto sbuf = dynamic_cast<Buffer*>(obj);
+      if (sbuf != nullptr) return new InputString (*sbuf);
+      // invalid object
+      throw Exception ("type-error", "invalid object with input string",
+		       Object::repr (obj));
     }
     throw Exception ("argument-error", 
 		     "invalid arguments with with input string");
