@@ -33,10 +33,14 @@ namespace afnix {
     /// create a new string stream without data
     InputString (void);
 
-    /// create a new string stream with a buffer
-    /// @param data the data in this input stream
+    /// create a string stream  by string
+    /// @param data the string data
     InputString (const String& data);
 
+    /// create a string stream by buffer
+    /// @param sbuf the string buffer
+    InputString (const Buffer& sbuf);
+
     /// @return the class name
     String repr (void) const override;
 
