@@ -30,6 +30,13 @@
 
 namespace afnix {
 
+  // -------------------------------------------------------------------------
+  // - private section                                                       -
+  // -------------------------------------------------------------------------
+
+  // the number format
+  const String Integer::CV_NUM_FRMT = "INTEGER";
+  
   // -------------------------------------------------------------------------
   // - public section                                                        -
   // -------------------------------------------------------------------------
@@ -757,7 +764,21 @@ namespace afnix {
       throw;
     }
   }
+  
+  // get the number format
 
+  String Integer::tofrmt (void) const {
+    rdlock ();
+    try {
+      String result = CV_NUM_FRMT;
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+    
   // return a native integer value
 
   t_long Integer::tolong (void) const {
