@@ -30,6 +30,9 @@ namespace afnix {
 
   class Integer : public Number {
   public:
+    // the number format
+    static const String CV_NUM_FRMT;
+    
     /// compute the opposite of the integer
     /// @param x the integer to oppose
     /// @return a new integer opposite of the argument
@@ -242,6 +245,9 @@ namespace afnix {
     /// @return a hexadecimal string
     String tohstr (void) const override;
 
+    /// @return the number format
+    String tofrmt (void) const override;
+    
     /// @return a native integer representation
     t_long tolong (void) const;
 
