@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2020 amaury darsch                                   -
+// - copyright (c) 1999-2021 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Item.hpp"
@@ -254,10 +254,11 @@ namespace afnix {
   Object* Item::oper (t_oper type, Object* object) {
     Item* iobj = dynamic_cast <Item*> (object);
     switch (type) {
-    case Object::EQL:
+    case Object::OPER_EQL:
+    case Object::OPER_QEQ:
       if (iobj != nullptr) return new Boolean (*this == *iobj);
       break;
-    case Object::NEQ:
+    case Object::OPER_NEQ:
       if (iobj != nullptr) return new Boolean (*this != *iobj);
       break;
     default:
@@ -295,11 +296,11 @@ namespace afnix {
     // dispatch 1 argument
     if (argc == 1) {
       if (quark == QUARK_EQL) {
-	Object* result = oper (Object::EQL, argv->get (0));
+	Object* result = oper (Object::OPER_EQL, argv->get (0));
 	return result;
       }
       if (quark == QUARK_NEQ) {
-	Object* result = oper (Object::NEQ, argv->get (0));
+	Object* result = oper (Object::OPER_NEQ, argv->get (0));
 	return result;
       }
     } 
