@@ -23,16 +23,31 @@ namespace afnix {
   // - class section                                                         -
   // -------------------------------------------------------------------------
 
-  // copy move this iterable - no lock since abstract
+  // copy move this iterable
 
-  Iterable::Iterable (Iterable&& that) noexcept :
-    Object (static_cast<Object&&>(that)) {
+  Iterable::Iterable (Iterable&& that) noexcept {
+    that.wrlock ();
+    try {
+      Object::operator = (static_cast<Object&&>(that));
+    } catch (...) {
+    }
+    that.unlock ();
   }
   
-  // move this iterable into this one - no lock since abstract
+  // move this iterable into this one
 
   Iterable& Iterable::operator = (Iterable&& that) noexcept {
-    Object::operator = (static_cast<Object&&>(that));
+    // check for self assignation
+    if (this == &that) return *this;
+    // lock and assign
+    wrlock ();
+    that.wrlock ();
+    try {
+      Object::operator = (static_cast<Object&&>(that));
+    } catch (...) {
+    }
+    unlock ();
+    that.unlock ();
     return *this;
   }
   
