@@ -26,16 +26,31 @@ namespace afnix {
   // - class section                                                         -
   // -------------------------------------------------------------------------
 
-  // copy move this iterator - no lock since abstract
+  // copy move this iterator
 
-  Iterator::Iterator (Iterator&& that) noexcept :
-    Object (static_cast<Object&&>(that)) {
+  Iterator::Iterator (Iterator&& that) noexcept {
+    that.wrlock ();
+    try {
+      Object::operator = (static_cast<Object&&>(that));
+    } catch (...) {
+    }
+    that.unlock ();
   }
   
-  // move this iterator into this one - no lock since abstract
+  // move this iterator into this one
 
   Iterator& Iterator::operator = (Iterator&& that) noexcept {
-    Object::operator = (static_cast<Object&&>(that));
+    // check for self assignation
+    if (this == &that) return *this;
+    // lock and assign
+    wrlock ();
+    that.wrlock ();
+    try {
+      Object::operator = (static_cast<Object&&>(that));
+    } catch (...) {
+    }
+    unlock ();
+    that.unlock ();
     return *this;
   }
   
