@@ -26,14 +26,29 @@ namespace afnix {
 
   // copy move this literal - no lock since abstract
 
-  Literal::Literal (Literal&& that) noexcept :
-    Serial (static_cast<Serial&&>(that)) {
+  Literal::Literal (Literal&& that) noexcept {
+    that.wrlock ();
+    try {
+      Object::operator = (static_cast<Serial&&>(that));
+    } catch (...) {
+    }
+    that.unlock ();
   }
   
   // move this literal into this one - no lock since abstract
 
   Literal& Literal::operator = (Literal&& that) noexcept {
-    Serial::operator = (static_cast<Serial&&>(that));
+    // check for self assignation
+    if (this == &that) return *this;
+    // lock and assign
+    wrlock ();
+    that.wrlock ();
+    try {
+      Object::operator = (static_cast<Serial&&>(that));
+    } catch (...) {
+    }
+    unlock ();
+    that.unlock ();
     return *this;
   }
   
