@@ -18,7 +18,7 @@
 #include "Date.hpp"
 #include "Vector.hpp"
 #include "Logger.hpp"
-#include "Global.hpp"
+#include "Common.hpp"
 #include "Utility.hpp"
 #include "Boolean.hpp"
 #include "Integer.hpp"
@@ -111,7 +111,7 @@ namespace afnix {
     p_os   = nullptr;
     d_size = LOGGER_SIZE;
     p_mlog = new s_mlog[d_size];
-    d_ldbg = Global::getdbug ();
+    d_ldbg = Common::getdbug ();
     reset ();
   }
   
@@ -121,7 +121,7 @@ namespace afnix {
     p_os   = nullptr;
     d_size = (size > 0) ? size : LOGGER_SIZE;
     p_mlog = new s_mlog[d_size];
-    d_ldbg = Global::getdbug ();
+    d_ldbg = Common::getdbug ();
     reset ();
   }
 
