@@ -69,7 +69,7 @@ namespace afnix {
     ~Logger (void);
 
     /// return the class name
-    String repr (void) const;
+    String repr (void) const override;
 
     /// reset this logger
     virtual void reset (void);
@@ -128,7 +128,7 @@ namespace afnix {
     static Object* mknew (Vector* argv);
 
     /// @return true if the given quark is defined
-    bool isquark (const long quark, const bool hflg) const;
+    bool isquark (const long quark, const bool hflg) const override;
 
     /// apply this object with a set of arguments and a quark
     /// @param zobj  the current evaluable
@@ -136,7 +136,7 @@ namespace afnix {
     /// @param quark the quark to apply these arguments
     /// @param argv  the arguments  to apply
     Object* apply (Evaluable* zobj, Nameset* nset, const long quark,
-		   Vector* argv);
+		   Vector* argv) override;
   };
 }
 
