@@ -172,99 +172,70 @@ namespace afnix {
   // compute the argument arc sine
 
   t_real Math::asin (const t_real x) {
-    bool   status = false;
-    t_real result = c_asin (x, status);
-    if (status == false) {
-      throw Exception ("math-error", "math error with asin call");
-    }
+    t_real result = c_asin (x);
     return result;
   }
 
   // compute the argument arc cosine
 
   t_real Math::acos (const t_real x) {
-    bool   status = false;
-    t_real result = c_acos (x, status);
-    if (status == false) {
-      throw Exception ("math-error", "math error with acos call");
-    }
+    t_real result = c_acos (x);
     return result;
   }
 
   // compute the argument arc tangent
 
   t_real Math::atan (const t_real x) {
-    bool   status = false;
-    t_real result = c_atan (x, status);
-    if (status == false) {
-      throw Exception ("math-error", "math error with atan call");
-    }
+    t_real result = c_atan (x);
+    return result;
+  }
+
+  // compute the argument arc tangent two
+
+  t_real Math::atan (const t_real x, const t_real y) {
+    t_real result = c_atan (x, y);
     return result;
   }
 
   // compute the argument hyperbolic sine
 
   t_real Math::sinh (const t_real x) {
-    bool   status = false;
-    t_real result = c_sinh (x, status);
-    if (status == false) {
-      throw Exception ("math-error", "math error with sinh call");
-    }
+    t_real result = c_sinh (x);
     return result;
   }
 
   // compute the argument hyperbolic cosine
 
   t_real Math::cosh (const t_real x) {
-    bool   status = false;
-    t_real result = c_cosh (x, status);
-    if (status == false) {
-      throw Exception ("math-error", "math error with cosh call");
-    }
+    t_real result = c_cosh (x);
     return result;
   }
 
   // compute the argument hyperbolic tangent
 
   t_real Math::tanh (const t_real x) {
-    bool   status = false;
-    t_real result = c_tanh (x, status);
-    if (status == false) {
-      throw Exception ("math-error", "math error with tanh call");
-    }
+    t_real result = c_tanh (x);
     return result;
   }
 
   // compute the argument arc hyperbolic sine
 
   t_real Math::asinh (const t_real x) {
-    bool   status = false;
-    t_real result = c_asinh (x, status);
-    if (status == false) {
-      throw Exception ("math-error", "math error with asinh call");
-    }
+    t_real result = c_asinh (x);
     return result;
   }
 
   // compute the argument arc hyperbolic cosine
 
   t_real Math::acosh (const t_real x) {
-    bool   status = false;
-    t_real result = c_acosh (x, status);
-    if (status == false) {
-      throw Exception ("math-error", "math error with acosh call");
-    }
+    t_real result = c_acosh (x);
     return result;
   }
 
   // compute the argument arc hyperbolic tangent
 
   t_real Math::atanh (const t_real x) {
-    bool   status = false;
-    t_real result = c_atanh (x, status);
-    if (status == false) {
-      throw Exception ("math-error", "math error with atanh call");
-    }
+    t_real result = c_atanh (x);
     return result;
   }
 
