@@ -138,6 +138,10 @@ namespace afnix {
     /// @param x the real argument
     static t_real atan (const t_real x);
 
+    /// compute the argument arc tangent two
+    /// @param x the real argument
+    static t_real atan (const t_real x, const t_real y);
+
     /// compute the argument hyperbolic sine
     /// @param x the real argument
     static t_real sinh (const t_real x);
