@@ -90,10 +90,12 @@ namespace afnix {
 
   // copy move this message
 
-  Message::Message (Message&& that) noexcept :
-    Taggable(static_cast<Taggable&&>(that)) {
+  Message::Message (Message&& that) noexcept {
     that.wrlock ();
     try {
+      // move base taggable
+      Taggable::operator =(static_cast<Taggable&&>(that));
+      // copy locally
       d_type = that.d_type; that.d_type = MESG_NONE;
       d_code = that.d_code; that.d_code = 0L;
       that.unlock ();
