@@ -26,14 +26,29 @@ namespace afnix {
 
   // copy move this nameable
 
-  Nameable::Nameable (Nameable&& that) noexcept :
-    Object (static_cast<Object&&>(that)) {
+  Nameable::Nameable (Nameable&& that) noexcept {
+    that.wrlock ();
+    try {
+      Object::operator = (static_cast<Object&&>(that));
+    } catch (...) {
+    }
+    that.unlock ();
   }
   
   // move this nameable into this one
 
   Nameable& Nameable::operator = (Nameable&& that) noexcept {
-    Object::operator = (static_cast<Object&&>(that));
+    // check for self assignation
+    if (this == &that) return *this;
+    // lock and assign
+    wrlock ();
+    that.wrlock ();
+    try {
+      Object::operator = (static_cast<Object&&>(that));
+    } catch (...) {
+    }
+    unlock ();
+    that.unlock ();
     return *this;
   }
 
