@@ -23,6 +23,13 @@
 
 namespace afnix {
 
+  // -------------------------------------------------------------------------
+  // - private section                                                       -
+  // -------------------------------------------------------------------------
+
+  // the number format
+  const String Number::CV_NIL_FRMT = "NIL";
+
   // -------------------------------------------------------------------------
   // - public section                                                        -
   // -------------------------------------------------------------------------
@@ -53,14 +60,29 @@ namespace afnix {
   
   // copy move this number - no lock since abstract
 
-  Number::Number (Number&& that) noexcept :
-    Literal (static_cast<Literal&&>(that)) {
+  Number::Number (Number&& that) noexcept {
+    that.wrlock ();
+    try {
+      Literal::operator = (static_cast<Literal&&>(that));
+    } catch (...) {
+    }
+    that.unlock ();
   }
   
   // move this number into this one - no lock since abstract
 
   Number& Number::operator = (Number&& that) noexcept {
-    Literal::operator = (static_cast<Literal&&>(that));
+    // check for self assignation
+    if (this == &that) return *this;
+    // lock and assign
+    wrlock ();
+    that.wrlock ();
+    try {
+      Literal::operator = (static_cast<Literal&&>(that));
+    } catch (...) {
+    }
+    unlock ();
+    that.unlock ();
     return *this;
   }
 
@@ -78,7 +100,21 @@ namespace afnix {
 		     "cannot generate a hexadecimal string", repr ());
   }
 
-  // return a formatted string in scientific notation
+  // get the number format
+
+  String Number::tofrmt (void) const {
+    rdlock ();
+    try {
+      String result = CV_NIL_FRMT;
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+  
+  // get a formatted string in scientific notation
 
   String Number::format (const bool sflg) const {
     rdlock ();
@@ -134,13 +170,14 @@ namespace afnix {
   // -------------------------------------------------------------------------
   
   // the quark zone
-  static const long QUARK_ZONE_LENGTH = 3;
+  static const long QUARK_ZONE_LENGTH = 4;
   static QuarkZone  zone (QUARK_ZONE_LENGTH);
 
   // the object supported quarks
   static const long QUARK_FORMAT = zone.intern ("format");
   static const long QUARK_TOHEXA = zone.intern ("to-hexa");
   static const long QUARK_TOHSTR = zone.intern ("to-hexa-string");
+  static const long QUARK_TOFRMT = zone.intern ("to-format");
 
   // return true if the given quark is defined
 
@@ -172,6 +209,7 @@ namespace afnix {
       if (quark == QUARK_FORMAT) return new String (format (0L));
       if (quark == QUARK_TOHEXA) return new String (tohexa ());
       if (quark == QUARK_TOHSTR) return new String (tohstr ());
+      if (quark == QUARK_TOFRMT) return new String (tofrmt ());
     }
     
     // dispatch 1 argument
