@@ -36,10 +36,13 @@ namespace afnix {
 
   class Number : public Literal, public Viewable {
   public:
-    /// check if a string is a decimal number
+    /// the nil number format
+    static const String CV_NIL_FRMT;
+    
+    /// @return true if a string is a decimal number
     static bool isdnum (const String& s);
 
-    /// check if a string is an hexadecimal number
+    /// @return true if a string is an hexadecimal number
     static bool ishnum (const String& s);
     
   public:
@@ -59,6 +62,9 @@ namespace afnix {
 
     /// @return a hexadecimal string of this number
     virtual String tohstr (void) const;
+
+    /// @return the number format
+    virtual String tofrmt (void) const;
     
     /// @return a formated string in scientific notation
     virtual String format (const bool sflg) const;
