@@ -35,8 +35,13 @@ namespace afnix {
   // - private section                                                       -
   // -------------------------------------------------------------------------
 
-  static const long QUARK_SINT = String::intern ("INTEGER");
-  static const long QUARK_SFLT = String::intern ("FLOAT");
+  // the number formats
+  const String Numeral::CV_FIX_FRMT = "FIXED";
+  const String Numeral::CV_FLT_FRMT = "FLOAT";
+
+  // the numeral type quark
+  static const long QUARK_SINT = String::intern (Numeral::CV_FIX_FRMT);
+  static const long QUARK_SFLT = String::intern (Numeral::CV_FLT_FRMT);
   static const long QUARK_NMRL = String::intern ("Numeral");
 
   // -------------------------------------------------------------------------
@@ -1166,8 +1171,29 @@ namespace afnix {
       throw;
     }
   }
-
-
+  
+  // get the number format
+  
+  String Numeral::tofrmt (void) const {
+    rdlock ();
+    try {
+      String result;
+      switch (d_numt) {
+      case NUMT_SINT:
+	result = CV_FIX_FRMT;
+	break;
+      case NUMT_SFLT:
+	result = CV_FLT_FRMT;
+	break;
+      }
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+  
   // return true if the number is 0
 
   bool Numeral::iszero (void) const {
