@@ -16,7 +16,7 @@
 
 #include "Vector.hpp"
 #include "System.hpp"
-#include "Global.hpp"
+#include "Common.hpp"
 #include "Options.hpp"
 #include "Boolean.hpp"
 #include "Unicode.hpp"
@@ -629,7 +629,7 @@ namespace afnix {
 	throw Exception ("options-error", "invalid option flag access", opte);
       }
       // set the debug flag
-      optd->setoflg (Global::getdbug ());
+      optd->setoflg (Common::getdbug ());
       unlock ();
     } catch (...) {
       unlock ();
@@ -664,7 +664,7 @@ namespace afnix {
       if(optc == nullptr) {
 	throw Exception ("options-error", "invalid option flag access", opte);
       }
-      optc->setoflg (Global::getdbug ());
+      optc->setoflg (Common::getdbug ());
       unlock ();
     } catch (...) {
       unlock ();
@@ -935,13 +935,18 @@ namespace afnix {
 
   bool Options::isquark (const long quark, const bool hflg) const {
     rdlock ();
-    if (zone.exists (quark) == true) {
+    try {
+      if (zone.exists (quark) == true) {
+	unlock ();
+	return true;
+      }      
+      bool result = hflg ? Object::isquark (quark, hflg) : false;
       unlock ();
-      return true;
-    }      
-    bool result = hflg ? Object::isquark (quark, hflg) : false;
-    unlock ();
-    return result;
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
   }
 
   // apply this object with a set of arguments and a quark
