@@ -63,33 +63,6 @@ namespace afnix {
     }
   }
 
-  // flush this output buffer
-  
-  void OutputBuffer::flush (void) {
-    wrlock ();
-    try {
-      d_sbuf.reset ();
-      unlock ();
-    } catch (...) {
-      unlock ();
-      throw;
-    }
-  }
-
-  // return the length of the output buffer
-
-  long OutputBuffer::length (void) const {
-    rdlock ();
-    try {
-      long result = d_sbuf.length ();
-      unlock ();
-      return result;
-    } catch (...) {
-      unlock ();
-      throw;
-    }
-  }
-
   // write one character to the output buffer
   
   long OutputBuffer::write (const char value) {
@@ -127,6 +100,33 @@ namespace afnix {
       throw;
     }
   }
+
+  // flush this output buffer
+  
+  void OutputBuffer::flush (void) {
+    wrlock ();
+    try {
+      d_sbuf.reset ();
+      unlock ();
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+
+  // return the length of the output buffer
+
+  long OutputBuffer::length (void) const {
+    rdlock ();
+    try {
+      long result = d_sbuf.length ();
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
   
   // return a buffer copy of the output buffer
 
@@ -191,7 +191,7 @@ namespace afnix {
   // -------------------------------------------------------------------------
 
   // the quark zone
-  static const long QUARK_ZONE_LENGTH = 3;
+  static const long QUARK_ZONE_LENGTH = 5;
   static QuarkZone  zone (QUARK_ZONE_LENGTH);
 
   // the object supported quarks
@@ -199,6 +199,7 @@ namespace afnix {
   static const long QUARK_LENGTH   = zone.intern ("length");
   static const long QUARK_FORMAT   = zone.intern ("format");
   static const long QUARK_TOSTRING = zone.intern ("to-string");
+  static const long QUARK_TOBUFFER = zone.intern ("to-buffer");
 
   // create a new object in a generic way
 
@@ -246,6 +247,7 @@ namespace afnix {
       if (quark == QUARK_LENGTH)   return new Integer (length   ());
       if (quark == QUARK_FORMAT)   return new String  (format   ());
       if (quark == QUARK_TOSTRING) return new String  (tostring ());
+      if (quark == QUARK_TOBUFFER) return new Buffer  (tobuffer ());
       if (quark == QUARK_FLUSH) {
 	flush ();
 	return nullptr;
