@@ -45,44 +45,44 @@ namespace afnix {
     OutputBuffer (const String& value);
 
     /// @return the class name
-    String repr (void) const;
+    String repr (void) const override;
 
     /// set the stream encoding mode
     /// @param emod the stream encoding mode to set
-    void setemod (const Encoding::t_emod emod);
-
-    /// flush this output buffer
-    void flush (void);
-
-    /// @return the length of this output buffer
-    long length (void) const;
+    void setemod (const Encoding::t_emod emod) override;
 
     /// write one character on the output buffer.
     /// @param value the character to write
-    long write (const char value);
+    long write (const char value) override;
 
     /// write a character string to the output buffer
     /// @param data the data to write  
-    long write (const char* data);
+    long write (const char* data) override;
+
+    /// flush this output buffer
+    virtual void flush (void);
+
+    /// @return the length of this output buffer
+    virtual long length (void) const;
 
     /// @return a copy of the stream buffer
-    Buffer tobuffer (void) const;
+    virtual Buffer tobuffer (void) const;
     
     /// @return a string representation of this output buffer
-    String tostring (void) const;
+    virtual String tostring (void) const;
 
     /// @return an octet string representation of this output buffer
-    String format (void) const;
+    virtual String format (void) const;
 
     /// send the output buffer content to an output stream
     /// @param os the output stream to write
-    void send (OutputStream* os);
+    virtual void send (OutputStream* os);
 
   private:
     // make the copy constructor private
-    OutputBuffer (const OutputBuffer&);
+    OutputBuffer (const OutputBuffer&) =delete;
     // make the assignment operator private
-    OutputBuffer& operator = (const OutputBuffer&);
+    OutputBuffer& operator = (const OutputBuffer&) =delete;
     
   public:
     /// create a new object in a generic way
@@ -90,7 +90,7 @@ namespace afnix {
     static Object* mknew (Vector* argv);
 
     /// @return true if the given quark is defined
-    bool isquark (const long quark, const bool hflg) const;
+    bool isquark (const long quark, const bool hflg) const override;
 
     /// apply this object with a set of arguments and a quark
     /// @param zobj  the current evaluable
@@ -98,7 +98,7 @@ namespace afnix {
     /// @param quark the quark to apply these arguments
     /// @param argv  the arguments to apply
     Object* apply (Evaluable* zobj, Nameset* nset, const long quark,
-		   Vector* argv);
+		   Vector* argv) override;
   };
 }
 
