@@ -60,35 +60,35 @@ namespace afnix {
     ~OutputFile (void);
 
     /// @return the class name
-    String repr (void) const;
+    String repr (void) const override;
 
     /// @return the stream descriptor
-    int getsid (void) const;
+    int getsid (void) const override;
 
     /// close this output file
-    bool close (void);
+    bool close (void) override;
 
     /// write one character on the output stream.
     /// @param value the character to write  
-    long write (const char value);
+    long write (const char value) override;
 
     /// write a character string to the output stream
     /// @param data the data to write
-    long write (const char* data);
+    long write (const char* data) override;
 
     /// write a character array to the output stream
     /// @param rbuf the reference buffer to write
     /// @param size the number of character to write
-    long write (const char* rbuf, const long size);
+    long write (const char* rbuf, const long size) override;
 
     /// @return the file name associated with this stream
-    String getname (void) const;
+    String getname (void) const override;
 
   private:
     // make the copy constructor private
-    OutputFile (const OutputFile&);
+    OutputFile (const OutputFile&) =delete;
     // make the assignment operator private
-    OutputFile& operator = (const OutputFile&);
+    OutputFile& operator = (const OutputFile&) =delete;
 
   public:
     /// create a new object in a generic way
@@ -96,7 +96,7 @@ namespace afnix {
     static Object* mknew (Vector* argv);
 
     /// @return true if the given quark is defined
-    bool isquark (const long quark, const bool hflg) const;
+    bool isquark (const long quark, const bool hflg) const override;
 
     /// apply this object with a set of arguments and a quark
     /// @param zobj  the current evaluable
@@ -104,7 +104,7 @@ namespace afnix {
     /// @param quark the quark to apply these arguments
     /// @param argv  the arguments to apply
     Object* apply (Evaluable* zobj, Nameset* nset, const long quark,
-		   Vector* argv);
+		   Vector* argv) override;
   };
 }
 
