@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2020 amaury darsch                                   -
+// - copyright (c) 1999-2021 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_PRIME_HPP
@@ -45,9 +45,16 @@ namespace afnix {
     /// @return true if the number is a probable prime number
     static bool isprobable (const Relatif& p);
 
+    /// @return true if the number is a safe prime number
+    static bool issafe (const Relatif& p);
+
     /// generate a random n bits prime number
     /// @param bits the number of bits
     static Relatif random (const long bits);
+
+    /// generate a random n bits safe prime number
+    /// @param bits the number of bits
+    static Relatif safe (const long bits);
   };
 }
 
