@@ -42,7 +42,7 @@ namespace afnix {
   // copy constructor for this quark array
 
   QuarkArray::QuarkArray (const QuarkArray& that) {
-    p_lary = new t_array<long> (*p_lary);
+    p_lary = new t_array<long> (*that.p_lary);
   }
 
   // destroy this quark array
