@@ -11,18 +11,18 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2020 amaury darsch                                   -
+// - copyright (c) 1999-2021 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_QUARKARRAY_HPP
 #define  AFNIX_QUARKARRAY_HPP
 
-#ifndef  AFNIX_STRING_HPP
-#include "String.hpp"
+#ifndef  AFNIX_BITS_HPP
+#include "Bits.hpp"
 #endif
 
-#ifndef  AFNIX_ARRAY_TCC
-#include "array.tcc"
+#ifndef  AFNIX_STRING_HPP
+#include "String.hpp"
 #endif
 
 namespace afnix {
@@ -33,10 +33,13 @@ namespace afnix {
   /// works with quarks only.
   /// @author amaury darsch
 
-  class QuarkArray : protected t_array<long> {
+  class QuarkArray {
+  protected:
+    t_array<long>* p_lary;
+    
   public:
     /// create an empty quark array
-    QuarkArray (void) =default;
+    QuarkArray (void);
 
     /// create a quark array with a predefined size
     /// @param size the requested size  
@@ -46,39 +49,42 @@ namespace afnix {
     /// @param that the quark array to copy
     QuarkArray (const QuarkArray& that);
 
+    /// destroy this quark array
+    virtual ~QuarkArray (void);
+    
     /// reset this quark array
-    void reset (void);
+    virtual void reset (void);
 
     /// @return the number of elements
-    long length (void) const;
+    virtual long length (void) const;
 
     /// add a quark in this array
     /// @param quark the quark to add
-    void add (const long quark);
+    virtual void add (const long quark);
 
     /// set a quark at a given position
     /// @param index the array index
     /// @param quark the quark to set
-    void set (const long index, const long quark);
+    virtual void set (const long index, const long quark);
 
     /// get a quark at a certain index
     /// @param index the vector index
-    long get (const long index) const;
+    virtual long get (const long index) const;
 
     /// @return true if the quark exists
-    bool exists (const long quark) const;
+    virtual bool exists (const long quark) const;
 
     /// get a quark index by quark or return -1
     /// @param quark the quark to search
-    long find (const long quark) const;
+    virtual long find (const long quark) const;
 
     /// get a quark index by quark or throw an exception
     /// @param quark the quark to search
-    long lookup (const long quark) const;
+    virtual long lookup (const long quark) const;
 
   private:
     // make the assignment operator private
-    QuarkArray& operator = (const QuarkArray&) = delete;
+    QuarkArray& operator = (const QuarkArray&) =delete;
   };
 }
 
