@@ -32,7 +32,14 @@
 namespace afnix {
 
   // -------------------------------------------------------------------------
-  // - public section                                                       -
+  // - private section                                                       -
+  // -------------------------------------------------------------------------
+
+  // the number format
+  const String Real::CV_NUM_FRMT = "REAL";
+
+  // -------------------------------------------------------------------------
+  // - public section                                                        -
   // -------------------------------------------------------------------------
 
   // compute the opposite of a real
@@ -352,7 +359,7 @@ namespace afnix {
     }
   }
 
-  // multiply a real with this one
+  // divide a real with this one
 
   Real& Real::operator /= (const Real& x) {
     wrlock   ();
@@ -584,7 +591,20 @@ namespace afnix {
       throw;
     }
   }
-
+  
+  // get the number format
+  
+  String Real::tofrmt (void) const {
+    rdlock ();
+    try {
+      String result = CV_NUM_FRMT;
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
 
   // return true if the number is 0
 
