@@ -31,6 +31,9 @@ namespace afnix {
 
   class Real : public Number {
   public:
+    // the number format
+    static const String CV_NUM_FRMT;
+    
     /// compute the opposite of the real
     /// @param x the real to oppose
     /// @return a new real opposite of the argument
@@ -206,6 +209,9 @@ namespace afnix {
     /// @return true if they are greater or equal
     bool operator >= (const Real& value) const;
 
+    /// @return the number format
+    String tofrmt (void) const override;
+
     /// compare this real with another one upto epsilon
     /// @param value the real value to compare
     bool cmp (const t_real value) const;
