@@ -30,7 +30,10 @@ namespace afnix {
   /// @author amaury darsch
 
   class Relatif : public Number {
-  public:    
+  public:
+    // the number format
+    static const String CV_NUM_FRMT;
+
     /// compute the greatest common divisor of two relatifs
     /// @param x the first relatif
     /// @param y the first relatif
@@ -319,6 +322,9 @@ namespace afnix {
     /// @param is the input steam to read in
     void rdstream (class InputStream& is) override;
 
+    /// @return the number format
+    String tofrmt (void) const override;
+
     /// @return true if this relatif is zero
     virtual bool iszero (void) const;
     
