@@ -805,16 +805,31 @@ namespace afnix {
   // - class section                                                         -
   // -------------------------------------------------------------------------
 
-  // copy move this serial - no lock since abstract
+  // copy move this serial
 
-  Serial::Serial (Serial&& that) noexcept :
-    Object (static_cast<Object&&>(that)) {
+  Serial::Serial (Serial&& that) noexcept {
+    that.wrlock ();
+    try {
+      Object::operator = (static_cast<Object&&>(that));
+    } catch (...) {
+    }
+    that.unlock ();
   }
   
-  // move this serial into this one - no lock since abstract
+  // move this serial into this one
 
   Serial& Serial::operator = (Serial&& that) noexcept {
-    Object::operator = (static_cast<Object&&>(that));
+    // check for self assignation
+    if (this == &that) return *this;
+    // lock and assign
+    wrlock ();
+    that.wrlock ();
+    try {
+      Object::operator = (static_cast<Object&&>(that));
+    } catch (...) {
+    }
+    unlock ();
+    that.unlock ();
     return *this;
   }
   
