@@ -143,7 +143,7 @@ namespace afnix {
     }
   }
 
-  // move a vector into this one
+  // move a set into this one
 
   Set& Set::operator = (Set&& that) noexcept {
     // check for self-move
@@ -177,6 +177,12 @@ namespace afnix {
     return "Set";
   }
 
+  // get a clone of this object
+
+  Object* Set::clone (void) const {
+    return new Set (*this);
+  }
+  
   // return the set did
 
   t_word Set::getdid (void) const {
