@@ -71,69 +71,72 @@ namespace afnix {
     Set& operator = (Set&& that) noexcept;
 
     /// @return the class name
-    String repr (void) const;
+    String repr (void) const override;
 
+    /// @return a clone of this object
+    Object* clone (void) const override;
+    
     /// @return the set did
-    t_word getdid (void) const;
+    t_word getdid (void) const override;
 
     /// @return the set sid
-    t_word getsid (void) const;
+    t_word getsid (void) const override;
 
     /// serialize this set cell to an output stream
     /// @param os the output stream to write
-    void wrstream (class OutputStream& os) const;
+    void wrstream (class OutputStream& os) const override;
 
     /// deserialize a set from an input stream
     /// @param is the input steam to read in
-    void rdstream (class InputStream& is);
+    void rdstream (class InputStream& is) override;
 
     /// reset this set
-    void reset (void);
+    virtual void reset (void);
 
     /// @return the cardinal of this set
-    long length (void) const;
+    virtual long length (void) const;
 
     /// @return an object by index
-    Object* get (const long index) const;
+    virtual Object* get (const long index) const;
 
     /// @return true if the set is empty
-    bool empty (void) const;
+    virtual bool empty (void) const;
 
     /// @return true if the object exists in this set
-    bool exists (Object* obj) const;
+    virtual bool exists (Object* obj) const;
 
     /// add an object to the set
     /// @param obj the object to add
-    void add (Object* obj);
+    virtual void add (Object* obj);
 
     /// remove an object from this set
     /// @param  obj  the object ot remove
     /// @return true if the object was removed
-    bool remove (Object* obj);
+    virtual bool remove (Object* obj);
 
     /// replace an object in this set
     /// @param  tobj the target object
     /// @return sobj the source object to replace
-    bool replace (Object* tobj, Object* sobj);
+    virtual bool replace (Object* tobj, Object* sobj);
 
     /// merge a set into this one
     /// @param cset he child set to merge
-    void merge (const Set& cset);
+    virtual void merge (const Set& cset);
 
     /// mix this set with a certain number of passes
     /// @param pnum the number of passes
-    void remix (const long pnum);
+    virtual void remix (const long pnum);
 
     /// get a random subset by size
     /// @param size the subset size
-    Set* getrss (const long size) const;
+    virtual Set* getrss (const long size) const;
 
     /// resize this set with a new size
     /// @para size the requested size
-    void resize (const long size);
+    virtual void resize (const long size);
 
     /// @return a new iterator for this set
-    Iterator* makeit (void);
+    Iterator* makeit (void) override;
 
   private:
     // make the set iterator a friend
@@ -145,7 +148,7 @@ namespace afnix {
     static Object* mknew (Vector* argv);
 
     /// @return true if the given quark is defined
-    bool isquark (const long quark, const bool hflg) const;
+    bool isquark (const long quark, const bool hflg) const override;
 
     /// apply this object with a set of arguments and a quark
     /// @param zobj  the current evaluable
@@ -153,7 +156,7 @@ namespace afnix {
     /// @param quark the quark to apply these arguments
     /// @param argv  the arguments to apply
     Object* apply (Evaluable* zobj, Nameset* nset, const long quark,
-		   Vector* argv);
+		   Vector* argv) override;
   };
   
   /// The Setit class is the iterator for the set class. Such iterator
@@ -177,31 +180,31 @@ namespace afnix {
     ~Setit (void);
 
     /// @return the class name
-    String repr (void) const;
+    String repr (void) const override;
 
     /// reset the iterator to the begining
-    void begin (void);
+    void begin (void) override;
 
     /// reset the iterator to the end
-    void end (void);
+    void end (void) override;
 
     /// move the iterator to the next position
-    void next (void);
+    void next (void) override;
 
     /// move the iterator to the previous position
-    void prev (void);
+    void prev (void) override;
 
     /// @return the object at the current position
-    Object* getobj (void) const;
+    Object* getobj (void) const override;
 
     /// @return true if the iterator is at the end
-    bool isend (void) const;
+    bool isend (void) const override;
 
   private:
     // make the copy constructor private
-    Setit (const Setit&);
+    Setit (const Setit&) =delete;
     // make the assignment operator private
-    Setit& operator = (const Setit&);
+    Setit& operator = (const Setit&) =delete;
   };
 }
 
