@@ -1394,44 +1394,49 @@ namespace afnix {
     Vector* result = new Vector;
     try {
       Strvec vec = Strvec::split (*this, sbrk);
-      long len = vec.length ();
+      long   len = vec.length ();
       for (long i = 0; i < len; i++) {
 	String data = vec.get (i);
 	result->add (new String (data));
       }
+      unlock ();
+      return result;
     } catch (...) {
       delete result;
       unlock ();
       throw;
     }
-    return result;
   }
 
   // accumulate strings between a control character
 
   Vector* String::extract (const t_quad cbrk) const {
     rdlock ();
-    Vector* result = new Vector;
-    long len = length ();
-    for (long i = 0; i < len; i++) {
-      t_quad c = p_sval[i];
-      if (c == cbrk) {
-	i++;
-	String buf;
-	while ((c = p_sval[i]) != cbrk) {
-	  buf += c ;
+    try {
+      Vector* result = new Vector;
+      long len = length ();
+      for (long i = 0; i < len; i++) {
+	t_quad c = p_sval[i];
+	if (c == cbrk) {
 	  i++;
-	  if (i == len) {
-	    delete result;
-	    unlock ();
-	    throw Exception ("extract-error", "unterminated string", *this);
+	  String buf;
+	  while ((c = p_sval[i]) != cbrk) {
+	    buf += c ;
+	    i++;
+	    if (i == len) {
+	      delete result;
+	      throw Exception ("extract-error", "unterminated string", *this);
+	    }
 	  }
+	  result->add (new String (buf));
 	}
-	result->add (new String (buf));
       }
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
     }
-    unlock ();
-    return result;
   }
 
   // -------------------------------------------------------------------------
