@@ -50,7 +50,7 @@ namespace afnix {
   Strvec Strvec::split (const String& name, const String& sbrk, 
 			const bool    uniq, const bool    zlen) {
     Strvec result (uniq); result.setzlen (zlen);
-    Buffer buffer;
+    Buffer buffer (Encoding::EMOD_UTF8);
     
     // first thing first - do we have a nil string
     if (name.length () == 0) return result;
