@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2020 amaury darsch                                   -
+// - copyright (c) 1999-2021 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_TIME_HPP
@@ -34,15 +34,17 @@ namespace afnix {
   class Time : public virtual Object {
   public:
     /// the number of seconds per minute
-    static const long MSEC = 60;
+    static const long  MSEC = 60;
     /// the number of minute per hour
-    static const long HMNS = 60;
+    static const long  HMNS = 60;
     /// the number of seconds per hour
-    static const long HSEC = HMNS * MSEC;
+    static const long  HSEC = HMNS * MSEC;
     /// the number of hours per day
-    static const long DHRS = 24;
+    static const long  DHRS = 24;
     /// the number of seconds per day
-    static const long DSEC = DHRS * HSEC;
+    static const long  DSEC = DHRS * HSEC;
+    /// the time now
+    static const char* TNOW;
     
     /// @return the current atc time
     static t_long gettclk (void);
@@ -69,7 +71,9 @@ namespace afnix {
   protected:
     /// the atc time
     t_long d_tclk;
-
+    /// the extension time
+    t_real d_eclk;
+    
   public:
     /// create the current time clock
     Time (void);
@@ -78,6 +82,11 @@ namespace afnix {
     /// @param tclk the atc time to use
     Time (const t_long tclk);
 
+    /// create a specific time clock
+    /// @param tclk the atc time to use
+    /// @param eclk the extended time
+    Time (const t_long tclk, const t_real eclk);
+    
     /// create a specific time clock
     /// @param hour the time hour
     /// @param mins the time minutes
@@ -98,10 +107,26 @@ namespace afnix {
     /// @param that the time object to assign
     Time& operator = (const Time& that);
 
+    /// compare two times
+    /// @param that the time to compare
+    bool operator == (const Time& that) const;
+
+    /// compare two times
+    /// @param that the time to compare
+    bool operator < (const Time& that) const;
+    
+    /// compare two times
+    /// @param that the time to compare
+    bool operator <= (const Time& that) const;
+    
     /// add a certain time to the atc clock
     /// @param tclk the time to add in seconds
     virtual void add (const t_long tclk);
 
+    /// add a time extension to the atc clock
+    /// @param eclk the extension to add
+    virtual void addext (const t_real eclk);
+
     /// set the atc clock in seconds
     /// @param tclk the time to set
     virtual void settime (const t_long tclk);
@@ -120,6 +145,10 @@ namespace afnix {
     /// @param utc the utc flag
     virtual t_long gettime (const bool utc) const;
 
+    /// get the extended clock in seconds
+    /// @param utc the utc flag
+    virtual t_real geteclk (const bool utc) const;
+
     /// @return the number of seconds
     virtual long getsecs (const bool utc) const;
 
@@ -144,6 +173,10 @@ namespace afnix {
     /// @param utc return in utc form if true
     virtual String torfc (const bool utc) const;
 
+    /// format the time as an extended time
+    /// @param utc return in utc form if true
+    virtual String toext (const bool utc) const;
+    
   public:
     /// create a new object in a generic way
     /// @param argv the argument vector
