@@ -56,32 +56,36 @@ namespace afnix {
     static t_byte tobyte (const char value);
     
     /// convert a string to a boolean
-    /// @param value the string to convert
-    static bool tobool (const String& value);
+    /// @param sval the string to convert
+    static bool tobool (const String& sval);
 
     /// convert a literal to a boolean
     /// @param lobj the literal to convert
     static bool tobool (Literal* lobj);
 
     /// convert a string to an integer boolean
-    /// @param value the string to convert
-    static bool toboil (const String& value);
+    /// @param sval the string to convert
+    static bool toboil (const String& sval);
 
     /// convert a literal to an integer boolean
     /// @param lobj the literal to convert
     static bool toboil (Literal* lobj);
 
     /// convert a string to an integer
-    /// @param value the string to convert
-    static t_long tolong (const String& value);
+    /// @param sval the string to convert
+    static t_long tolong (const String& sval);
 
     /// convert a literal to an integer
     /// @param lobj the literal to convert
     static t_long tolong (Literal* lobj);
 
     /// convert a string to a real
-    /// @param value the string to convert
-    static t_real toreal (const String& value);
+    /// @param sval the string to convert
+    static t_real toreal (const String& sval);
+
+    /// convert a string to a complex
+    /// @param sval the string to convert
+    static void tocplx (t_real zval[2], const String& sval);
 
     /// convert a literal to a real
     /// @param lobj the literal to convert
