@@ -21,7 +21,7 @@ int main (int, char**) {
 
   // the property name and value
   String name = "afnix";
-  String anam = "aws";
+  String anam = "xinfa";
   String pval = "programming language";
 
   // create an alias table
@@ -33,22 +33,26 @@ int main (int, char**) {
   // check existence
   if (atbl.exists  (name) == false) return 1;
   if (atbl.isalias (anam) == false) return 1;
-
   // check mapping
   if (atbl.map   (name) != anam) return 1;
   if (atbl.remap (anam) != name) return 1;
 
-  // create a new plist
+  // create a plist
   Plist plst;  
   plst.add (name, pval);
-  
   // map the plist
   Plist alst = atbl.map (plst);
   if (alst.length () != 1) return 1;
-  
   // check existence
   if (alst.exists (anam) == false) return 1;
   if (alst.exists (anam, pval) == false) return 1;
+
+  // create a hash table
+  HashTable htbl;
+  htbl.add (name, new String (pval));
+  // map the table
+  HashTable mtbl = atbl.map (htbl);
+  if (mtbl.length () != 1) return 1;
   
   // ok - everything is fine
   return 0;
