@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2020 amaury darsch                                   -
+// - copyright (c) 1999-2021 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Ascii.hpp"
@@ -110,8 +110,8 @@ int main (int, char**) {
   buffer->reset ();
   buffer->add ("hello:world:");
   if (buffer->extract(0L, 5L).tostring () != "hello") return 1;
-  if (buffer->collect(5L).tostring () != "hello") return 1;
-  if (buffer->tostring() != ":world:") return 1;
+  if (buffer->collect(7L).tostring () != ":world:") return 1;
+  if (buffer->tostring() != "hello") return 1;
   // finally - no failure
   delete bbuf;
   delete buffer;
